# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/admin/v1/admin.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/admin/v1/admin.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from tars.auth.v1 import auth_options_pb2 as tars_dot_auth_dot_v1_dot_auth__options__pb2
from tars.docs.v1 import docs_pb2 as tars_dot_docs_dot_v1_dot_docs__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19tars/admin/v1/admin.proto\x12\rtars.admin.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1ftars/auth/v1/auth_options.proto\x1a\x17tars/docs/v1/docs.proto\"\r\n\x0bPingRequest\"b\n\x0cPingResponse\x12\x18\n\x07message\x18\x01 \x01(\tR\x07message\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\"\x92\x04\n\x16\x43reateWorkspaceRequest\x12K\n\x0b\x63ustomer_id\x18\x01 \x01(\tB*\xbaH\'r%\x10\x01\x18?2\x1f^[a-z0-9]([a-z0-9-]*[a-z0-9])?$R\ncustomerId\x12@\n\x0cworkspace_id\x18\x02 \x01(\tB\x1d\xbaH\x1ar\x18\x10\x01\x18\xfd\x01\x32\x11^[a-zA-Z0-9-_.]+$R\x0bworkspaceId\x12!\n\x04name\x18\x03 \x01(\tB\x08\xbaH\x05r\x03\x18\xff\x01H\x00R\x04name\x88\x01\x01\x12/\n\x0b\x64\x65scription\x18\x04 \x01(\tB\x08\xbaH\x05r\x03\x18\xe8\x07H\x01R\x0b\x64\x65scription\x88\x01\x01\x12\x83\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x31.tars.admin.v1.CreateWorkspaceRequest.LabelsEntryB8\xbaH5\x9a\x01\x32\x10\x32\"\'r%\x18?2!^[a-z0-9]([a-z0-9-_.]*[a-z0-9])?$*\x05r\x03\x18\xff\x01R\x06labels\x12,\n\nproject_id\x18\x06 \x01(\tB\x08\xbaH\x05r\x03\x18\xfd\x01H\x02R\tprojectId\x88\x01\x01\x1a\x39\n\x0bLabelsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x07\n\x05_nameB\x0e\n\x0c_descriptionB\r\n\x0b_project_id\"Q\n\x17\x43reateWorkspaceResponse\x12\x36\n\tworkspace\x18\x01 \x01(\x0b\x32\x18.tars.admin.v1.WorkspaceR\tworkspace\"\xe6\x01\n\x15ListWorkspacesRequest\x12N\n\x0b\x63ustomer_id\x18\x01 \x01(\tB(\xbaH%r#\x18?2\x1f^[a-z0-9]([a-z0-9-]*[a-z0-9])?$H\x00R\ncustomerId\x88\x01\x01\x12,\n\tpage_size\x18\x02 \x01(\x05\x42\n\xbaH\x07\x1a\x05\x18\xe8\x07(\x00H\x01R\x08pageSize\x88\x01\x01\x12\"\n\npage_token\x18\x03 \x01(\tH\x02R\tpageToken\x88\x01\x01\x42\x0e\n\x0c_customer_idB\x0c\n\n_page_sizeB\r\n\x0b_page_token\"z\n\x16ListWorkspacesResponse\x12\x38\n\nworkspaces\x18\x01 \x03(\x0b\x32\x18.tars.admin.v1.WorkspaceR\nworkspaces\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"l\n\x13GetWorkspaceRequest\x12U\n\x02id\x18\x01 \x01(\tBE\xbaHBr@2>^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$R\x02id\"N\n\x14GetWorkspaceResponse\x12\x36\n\tworkspace\x18\x01 \x01(\x0b\x32\x18.tars.admin.v1.WorkspaceR\tworkspace\"\x9d\x03\n\x16UpdateWorkspaceRequest\x12U\n\x02id\x18\x01 \x01(\tBE\xbaHBr@2>^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$R\x02id\x12!\n\x04name\x18\x02 \x01(\tB\x08\xbaH\x05r\x03\x18\xff\x01H\x00R\x04name\x88\x01\x01\x12/\n\x0b\x64\x65scription\x18\x03 \x01(\tB\x08\xbaH\x05r\x03\x18\xe8\x07H\x01R\x0b\x64\x65scription\x88\x01\x01\x12\x83\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x31.tars.admin.v1.UpdateWorkspaceRequest.LabelsEntryB8\xbaH5\x9a\x01\x32\x10\x32\"\'r%\x18?2!^[a-z0-9]([a-z0-9-_.]*[a-z0-9])?$*\x05r\x03\x18\xff\x01R\x06labels\x1a\x39\n\x0bLabelsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x07\n\x05_nameB\x0e\n\x0c_description\"Q\n\x17UpdateWorkspaceResponse\x12\x36\n\tworkspace\x18\x01 \x01(\x0b\x32\x18.tars.admin.v1.WorkspaceR\tworkspace\"\xb0\x01\n\x1aSetWorkspaceProjectRequest\x12U\n\x02id\x18\x01 \x01(\tBE\xbaHBr@2>^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$R\x02id\x12,\n\nproject_id\x18\x02 \x01(\tB\x08\xbaH\x05r\x03\x18\xff\x01H\x00R\tprojectId\x88\x01\x01\x42\r\n\x0b_project_id\"U\n\x1bSetWorkspaceProjectResponse\x12\x36\n\tworkspace\x18\x01 \x01(\x0b\x32\x18.tars.admin.v1.WorkspaceR\tworkspace\"\xb4\x01\n\x16SetWorkspaceURLRequest\x12U\n\x02id\x18\x01 \x01(\tBE\xbaHBr@2>^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$R\x02id\x12\x1c\n\x03url\x18\x02 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\x80\x10R\x03url\x12%\n\x0etrigger_update\x18\x03 \x01(\x08R\rtriggerUpdate\"Q\n\x17SetWorkspaceURLResponse\x12\x36\n\tworkspace\x18\x01 \x01(\x0b\x32\x18.tars.admin.v1.WorkspaceR\tworkspace\"o\n\x16\x44\x65leteWorkspaceRequest\x12U\n\x02id\x18\x01 \x01(\tBE\xbaHBr@2>^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$R\x02id\"n\n\x17\x44\x65leteWorkspaceResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12\x39\n\ndeleted_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tdeletedAt\"\x95\x04\n\tWorkspace\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1f\n\x0b\x63ustomer_id\x18\x02 \x01(\tR\ncustomerId\x12!\n\x0cworkspace_id\x18\x03 \x01(\tR\x0bworkspaceId\x12\x17\n\x04name\x18\x04 \x01(\tH\x00R\x04name\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x05 \x01(\tH\x01R\x0b\x64\x65scription\x88\x01\x01\x12<\n\x06labels\x18\x06 \x03(\x0b\x32$.tars.admin.v1.Workspace.LabelsEntryR\x06labels\x12\x39\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x12>\n\ndeleted_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x02R\tdeletedAt\x88\x01\x01\x12\x1d\n\nproject_id\x18\n \x01(\tR\tprojectId\x1a\x39\n\x0bLabelsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x07\n\x05_nameB\x0e\n\x0c_descriptionB\r\n\x0b_deleted_at\"\xe3\x0b\n\x1b\x43reateServiceAccountRequest\x12K\n\x0b\x63ustomer_id\x18\x01 \x01(\tB*\xbaH\'r%\x10\x01\x18?2\x1f^[a-z0-9]([a-z0-9-]*[a-z0-9])?$R\ncustomerId\x12@\n\x0cworkspace_id\x18\x02 \x01(\tB\x1d\xbaH\x1ar\x18\x10\x01\x18\xfd\x01\x32\x11^[a-zA-Z0-9-_.]+$R\x0bworkspaceId\x12\x34\n\rvalidity_days\x18\x03 \x01(\x03\x42\n\xbaH\x07\"\x05\x18\xc2\x1c(\x01H\x00R\x0cvalidityDays\x88\x01\x01\x12&\n\x07\x61pi_uri\x18\x04 \x01(\tB\x08\xbaH\x05r\x03\x88\x01\x01H\x01R\x06\x61piUri\x88\x01\x01\x12*\n\tserve_url\x18\x12 \x01(\tB\x08\xbaH\x05r\x03\x88\x01\x01H\x02R\x08serveUrl\x88\x01\x01\x12%\n\x06issuer\x18\x05 \x01(\tB\x08\xbaH\x05r\x03\x88\x01\x01H\x03R\x06issuer\x88\x01\x01\x12<\n\x08\x61udience\x18\x06 \x01(\tB\x1b\xbaH\x18r\x16\x18\xfd\x01\x32\x11^[a-zA-Z0-9._-]+$H\x04R\x08\x61udience\x88\x01\x01\x12(\n\x08jwks_uri\x18\x07 \x01(\tB\x08\xbaH\x05r\x03\x88\x01\x01H\x05R\x07jwksUri\x88\x01\x01\x12\x32\n\x12telemetry_endpoint\x18\x08 \x01(\tH\x06R\x11telemetryEndpoint\x88\x01\x01\x12[\n\x12telemetry_protocol\x18\t \x01(\tB\'\xbaH$r\"R\x00R\x04grpcR\rhttp/protobufR\thttp/jsonH\x07R\x11telemetryProtocol\x88\x01\x01\x12\x32\n\x12telemetry_insecure\x18\n \x01(\x08H\x08R\x11telemetryInsecure\x88\x01\x01\x12Q\n\x11telemetry_timeout\x18\x0b \x01(\tB\x1f\xbaH\x1cr\x1a\x32\x18^[0-9]+(ns|us|ms|s|m|h)$H\tR\x10telemetryTimeout\x88\x01\x01\x12m\n\x11telemetry_headers\x18\x0c \x03(\x0b\x32@.tars.admin.v1.CreateServiceAccountRequest.TelemetryHeadersEntryR\x10telemetryHeaders\x12\x33\n\x06scopes\x18\r \x03(\tB\x1b\xbaH\x18\x92\x01\x15\x08\x00\x10\n\"\x0fr\r\x18\x32\x32\t^[a-z_]+$R\x06scopes\x12,\n\nrouter_url\x18\x0e \x01(\tB\x08\xbaH\x05r\x03\x88\x01\x01H\nR\trouterUrl\x88\x01\x01\x12\"\n\nrouter_key\x18\x0f \x01(\tH\x0bR\trouterKey\x88\x01\x01\x12-\n\x10internal_api_key\x18\x10 \x01(\tH\x0cR\x0einternalApiKey\x88\x01\x01\x12t\n\x14telemetry_local_vars\x18\x11 \x03(\x0b\x32\x42.tars.admin.v1.CreateServiceAccountRequest.TelemetryLocalVarsEntryR\x12telemetryLocalVars\x1a\x43\n\x15TelemetryHeadersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a\x45\n\x17TelemetryLocalVarsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x10\n\x0e_validity_daysB\n\n\x08_api_uriB\x0c\n\n_serve_urlB\t\n\x07_issuerB\x0b\n\t_audienceB\x0b\n\t_jwks_uriB\x15\n\x13_telemetry_endpointB\x15\n\x13_telemetry_protocolB\x15\n\x13_telemetry_insecureB\x14\n\x12_telemetry_timeoutB\r\n\x0b_router_urlB\r\n\x0b_router_keyB\x13\n\x11_internal_api_key\"\xb1\x01\n\x1c\x43reateServiceAccountResponse\x12\x46\n\x0fservice_account\x18\x01 \x01(\x0b\x32\x1d.tars.admin.v1.ServiceAccountR\x0eserviceAccount\x12\x1a\n\x08\x63hecksum\x18\x02 \x01(\tR\x08\x63hecksum\x12-\n\x12\x63hecksum_algorithm\x18\x03 \x01(\tR\x11\x63hecksumAlgorithm\"\xee\x04\n\x0eServiceAccount\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12\x1f\n\x0b\x63ustomer_id\x18\x03 \x01(\tR\ncustomerId\x12!\n\x0cworkspace_id\x18\x04 \x01(\tR\x0bworkspaceId\x12!\n\x0c\x63lient_email\x18\x05 \x01(\tR\x0b\x63lientEmail\x12$\n\x0eprivate_key_id\x18\x06 \x01(\tR\x0cprivateKeyId\x12\x1f\n\x0bprivate_key\x18\x07 \x01(\tR\nprivateKey\x12\x17\n\x07\x61pi_uri\x18\x08 \x01(\tR\x06\x61piUri\x12\x1b\n\tserve_url\x18\x0f \x01(\tR\x08serveUrl\x12@\n\x0b\x61uth_server\x18\t \x01(\x0b\x32\x1f.tars.admin.v1.AuthServerConfigR\nauthServer\x12?\n\ngatekeeper\x18\n \x01(\x0b\x32\x1f.tars.admin.v1.GatekeeperConfigR\ngatekeeper\x12\x43\n\x0c\x64\x61ta_exports\x18\x0b \x01(\x0b\x32 .tars.admin.v1.DataExportsConfigR\x0b\x64\x61taExports\x12\x16\n\x06scopes\x18\x0c \x03(\tR\x06scopes\x12\x39\n\ncreated_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nexpires_at\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.TimestampR\texpiresAt\"\x9c\x01\n\x10\x41uthServerConfig\x12\x16\n\x06issuer\x18\x01 \x01(\tR\x06issuer\x12\x1a\n\x08\x61udience\x18\x02 \x01(\tR\x08\x61udience\x12\x19\n\x08jwks_uri\x18\x03 \x01(\tR\x07jwksUri\x12\x39\n\x0bpublic_keys\x18\x04 \x03(\x0b\x32\x18.tars.admin.v1.PublicKeyR\npublicKeys\"\xb6\x01\n\x10GatekeeperConfig\x12\x16\n\x06issuer\x18\x01 \x01(\tR\x06issuer\x12\x1a\n\x08\x61udience\x18\x02 \x01(\tR\x08\x61udience\x12\x39\n\x0bpublic_keys\x18\x03 \x03(\x0b\x32\x18.tars.admin.v1.PublicKeyR\npublicKeys\x12\x33\n\x06router\x18\x04 \x01(\x0b\x32\x1b.tars.admin.v1.RouterConfigR\x06router\"<\n\x0cRouterConfig\x12\x1a\n\x03url\x18\x01 \x01(\tB\x08\xbaH\x05r\x03\x88\x01\x01R\x03url\x12\x10\n\x03key\x18\x02 \x01(\tR\x03key\"S\n\tPublicKey\x12\x10\n\x03kid\x18\x01 \x01(\tR\x03kid\x12\x10\n\x03\x61lg\x18\x02 \x01(\tR\x03\x61lg\x12\x10\n\x03use\x18\x03 \x01(\tR\x03use\x12\x10\n\x03key\x18\x04 \x01(\tR\x03key\"Q\n\x11\x44\x61taExportsConfig\x12<\n\ttelemetry\x18\x01 \x01(\x0b\x32\x1e.tars.admin.v1.TelemetryConfigR\ttelemetry\"\x82\x02\n\x0fTelemetryConfig\x12\x1a\n\x08\x65ndpoint\x18\x01 \x01(\tR\x08\x65ndpoint\x12\x1a\n\x08protocol\x18\x02 \x01(\tR\x08protocol\x12\x1a\n\x08insecure\x18\x03 \x01(\x08R\x08insecure\x12\x18\n\x07timeout\x18\x04 \x01(\tR\x07timeout\x12\x45\n\x07headers\x18\x05 \x03(\x0b\x32+.tars.admin.v1.TelemetryConfig.HeadersEntryR\x07headers\x1a:\n\x0cHeadersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\x8e\x03\n\x1aListServiceAccountsRequest\x12N\n\x0b\x63ustomer_id\x18\x01 \x01(\tB(\xbaH%r#\x18?2\x1f^[a-z0-9]([a-z0-9-]*[a-z0-9])?$H\x00R\ncustomerId\x88\x01\x01\x12\x43\n\x0cworkspace_id\x18\x02 \x01(\tB\x1b\xbaH\x18r\x16\x18\xfd\x01\x32\x11^[a-zA-Z0-9-_.]+$H\x01R\x0bworkspaceId\x88\x01\x01\x12@\n\x06status\x18\x03 \x01(\x0e\x32#.tars.admin.v1.ServiceAccountStatusH\x02R\x06status\x88\x01\x01\x12,\n\tpage_size\x18\x04 \x01(\x05\x42\n\xbaH\x07\x1a\x05\x18\xe8\x07(\x00H\x03R\x08pageSize\x88\x01\x01\x12\"\n\npage_token\x18\x05 \x01(\tH\x04R\tpageToken\x88\x01\x01\x42\x0e\n\x0c_customer_idB\x0f\n\r_workspace_idB\t\n\x07_statusB\x0c\n\n_page_sizeB\r\n\x0b_page_token\"\x93\x01\n\x1bListServiceAccountsResponse\x12L\n\x10service_accounts\x18\x01 \x03(\x0b\x32!.tars.admin.v1.ServiceAccountInfoR\x0fserviceAccounts\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"q\n\x18GetServiceAccountRequest\x12U\n\x02id\x18\x01 \x01(\tBE\xbaHBr@2>^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$R\x02id\"g\n\x19GetServiceAccountResponse\x12J\n\x0fservice_account\x18\x01 \x01(\x0b\x32!.tars.admin.v1.ServiceAccountInfoR\x0eserviceAccount\"\x94\x05\n\x12ServiceAccountInfo\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1f\n\x0b\x63ustomer_id\x18\x02 \x01(\tR\ncustomerId\x12!\n\x0cworkspace_id\x18\x03 \x01(\tR\x0bworkspaceId\x12\x14\n\x05\x65mail\x18\x04 \x01(\tR\x05\x65mail\x12;\n\x06status\x18\x05 \x01(\x0e\x32#.tars.admin.v1.ServiceAccountStatusR\x06status\x12\x39\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nexpires_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\texpiresAt\x12\x41\n\x0clast_used_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\nlastUsedAt\x88\x01\x01\x12\x34\n\x16public_key_fingerprint\x18\t \x01(\tR\x14publicKeyFingerprint\x12K\n\x08metadata\x18\n \x03(\x0b\x32/.tars.admin.v1.ServiceAccountInfo.MetadataEntryR\x08metadata\x12>\n\nrevoked_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01R\trevokedAt\x88\x01\x01\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x0f\n\r_last_used_atB\r\n\x0b_revoked_at\"\xa6\x01\n\x1bRevokeServiceAccountRequest\x12U\n\x02id\x18\x01 \x01(\tBE\xbaHBr@2>^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$R\x02id\x12%\n\x06reason\x18\x02 \x01(\tB\x08\xbaH\x05r\x03\x18\xf4\x03H\x00R\x06reason\x88\x01\x01\x42\t\n\x07_reason\"s\n\x1cRevokeServiceAccountResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12\x39\n\nrevoked_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\trevokedAt\"\xa7\x01\n\x1cRestoreServiceAccountRequest\x12U\n\x02id\x18\x01 \x01(\tBE\xbaHBr@2>^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$R\x02id\x12%\n\x06reason\x18\x02 \x01(\tB\x08\xbaH\x05r\x03\x18\xf4\x03H\x00R\x06reason\x88\x01\x01\x42\t\n\x07_reason\"\x85\x01\n\x1dRestoreServiceAccountResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12J\n\x0fservice_account\x18\x02 \x01(\x0b\x32!.tars.admin.v1.ServiceAccountInfoR\x0eserviceAccount\"\xef\x04\n\x16\x43reateUserTokenRequest\x12\x39\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x18\xbaH\x15r\x13\x10\x01\x18\x64\x32\r^[a-z0-9_-]+$R\ncustomerId\x12;\n\x0cworkspace_id\x18\x02 \x01(\tB\x18\xbaH\x15r\x13\x10\x01\x18\x64\x32\r^[a-z0-9_-]+$R\x0bworkspaceId\x12#\n\x07user_id\x18\x03 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xff\x01R\x06userId\x12\x1d\n\x04role\x18\x04 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18\x64R\x04role\x12\x37\n\x11organization_unit\x18\x05 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xff\x01R\x10organizationUnit\x12\x37\n\x0f\x65xpires_in_days\x18\x06 \x01(\x03\x42\n\xbaH\x07\"\x05\x18\xed\x02(\x01H\x00R\rexpiresInDays\x88\x01\x01\x12\x33\n\x06scopes\x18\x07 \x03(\tB\x1b\xbaH\x18\x92\x01\x15\x08\x00\x10\n\"\x0fr\r\x18\x32\x32\t^[a-z_]+$R\x06scopes\x12!\n\x04name\x18\x08 \x01(\tB\x08\xbaH\x05r\x03\x18\xff\x01H\x01R\x04name\x88\x01\x01\x12%\n\x0bimpersonate\x18\t \x01(\x08H\x02R\x0bimpersonate\x88\x01\x01\x12`\n\x16impersonation_metadata\x18\n \x01(\x0b\x32$.tars.admin.v1.ImpersonationMetadataH\x03R\x15impersonationMetadata\x88\x01\x01\x42\x12\n\x10_expires_in_daysB\x07\n\x05_nameB\x0e\n\x0c_impersonateB\x19\n\x17_impersonation_metadata\"\x89\x02\n\x15ImpersonationMetadata\x12\x35\n\x10impersonator_key\x18\x01 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xff\x01R\x0fimpersonatorKey\x12%\n\x06reason\x18\x02 \x01(\tB\x08\xbaH\x05r\x03\x18\xf4\x03H\x00R\x06reason\x88\x01\x01\x12K\n\x07\x63ontext\x18\x03 \x03(\x0b\x32\x31.tars.admin.v1.ImpersonationMetadata.ContextEntryR\x07\x63ontext\x1a:\n\x0c\x43ontextEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\t\n\x07_reason\"\xa2\x02\n\x17\x43reateUserTokenResponse\x12!\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\tR\x0b\x61\x63\x63\x65ssToken\x12\x1d\n\ntoken_type\x18\x02 \x01(\tR\ttokenType\x12\x1d\n\nexpires_in\x18\x03 \x01(\x03R\texpiresIn\x12\x39\n\nexpires_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\texpiresAt\x12\x10\n\x03jti\x18\x05 \x01(\tR\x03jti\x12\x1d\n\nkey_prefix\x18\x06 \x01(\tR\tkeyPrefix\x12\x19\n\x08key_hash\x18\x07 \x01(\tR\x07keyHash\x12\x1f\n\x0bkey_address\x18\x08 \x01(\tR\nkeyAddress\"\x82\x02\n\x15ListUserTokensRequest\x12&\n\x07user_id\x18\x01 \x01(\tB\x08\xbaH\x05r\x03\x18\xff\x01H\x00R\x06userId\x88\x01\x01\x12;\n\x06status\x18\x02 \x01(\x0e\x32\x1e.tars.admin.v1.UserTokenStatusH\x01R\x06status\x88\x01\x01\x12,\n\tpage_size\x18\x03 \x01(\x05\x42\n\xbaH\x07\x1a\x05\x18\xe8\x07(\x00H\x02R\x08pageSize\x88\x01\x01\x12\"\n\npage_token\x18\x04 \x01(\tH\x03R\tpageToken\x88\x01\x01\x42\n\n\x08_user_idB\t\n\x07_statusB\x0c\n\n_page_sizeB\r\n\x0b_page_token\"v\n\x16ListUserTokensResponse\x12\x34\n\x06tokens\x18\x01 \x03(\x0b\x32\x1c.tars.admin.v1.UserTokenInfoR\x06tokens\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"2\n\x13GetUserTokenRequest\x12\x1b\n\x03jti\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18@R\x03jti\"J\n\x14GetUserTokenResponse\x12\x32\n\x05token\x18\x01 \x01(\x0b\x32\x1c.tars.admin.v1.UserTokenInfoR\x05token\"\x8b\x04\n\rUserTokenInfo\x12\x10\n\x03jti\x18\x01 \x01(\tR\x03jti\x12\x17\n\x07user_id\x18\x02 \x01(\tR\x06userId\x12\x12\n\x04role\x18\x03 \x01(\tR\x04role\x12+\n\x11organization_unit\x18\x04 \x01(\tR\x10organizationUnit\x12\x36\n\x06status\x18\x05 \x01(\x0e\x32\x1e.tars.admin.v1.UserTokenStatusR\x06status\x12\x39\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nexpires_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\texpiresAt\x12\x41\n\x0clast_used_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\nlastUsedAt\x88\x01\x01\x12>\n\nrevoked_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01R\trevokedAt\x88\x01\x01\x12*\n\x0erevoked_reason\x18\n \x01(\tH\x02R\rrevokedReason\x88\x01\x01\x42\x0f\n\r_last_used_atB\r\n\x0b_revoked_atB\x11\n\x0f_revoked_reason\"g\n\x16RevokeUserTokenRequest\x12\x1b\n\x03jti\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18@R\x03jti\x12%\n\x06reason\x18\x02 \x01(\tB\x08\xbaH\x05r\x03\x18\xf4\x03H\x00R\x06reason\x88\x01\x01\x42\t\n\x07_reason\"n\n\x17RevokeUserTokenResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12\x39\n\nrevoked_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\trevokedAt\"\x9c\x04\n\x19TelemetryForwardingConfig\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x17\n\x07user_id\x18\x02 \x01(\tR\x06userId\x12%\n\x0etelemetry_type\x18\x03 \x01(\tR\rtelemetryType\x12\x19\n\x08sink_url\x18\x04 \x01(\tR\x07sinkUrl\x12\x1a\n\x08protocol\x18\x05 \x01(\tR\x08protocol\x12\x1b\n\tauth_type\x18\x06 \x01(\tR\x08\x61uthType\x12\"\n\nauth_value\x18\x07 \x01(\tH\x00R\tauthValue\x88\x01\x01\x12)\n\x0e\x61pi_key_header\x18\x08 \x01(\tH\x01R\x0c\x61piKeyHeader\x88\x01\x01\x12\x18\n\x07\x65nabled\x18\t \x01(\x08R\x07\x65nabled\x12\x42\n\x0flast_checked_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampR\rlastCheckedAt\x12\x16\n\x06status\x18\x0b \x01(\tR\x06status\x12\x39\n\ncreated_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAtB\r\n\x0b_auth_valueB\x11\n\x0f_api_key_header\"\xd7\x03\n\x1c\x43reateTelemetryConfigRequest\x12 \n\x07user_id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x06userId\x12\x43\n\x0etelemetry_type\x18\x02 \x01(\tB\x1c\xbaH\x19r\x17R\x06tracesR\x07metricsR\x04logsR\rtelemetryType\x12%\n\x08sink_url\x18\x03 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x88\x01\x01R\x07sinkUrl\x12\x41\n\x08protocol\x18\x04 \x01(\tB%\xbaH\"r R\x04grpcR\thttp/jsonR\rhttp/protobufR\x08protocol\x12@\n\tauth_type\x18\x05 \x01(\tB#\xbaH r\x1eR\x04noneR\x06\x62\x65\x61rerR\x05\x62\x61sicR\x07\x61pi_keyR\x08\x61uthType\x12\"\n\nauth_value\x18\x06 \x01(\tH\x00R\tauthValue\x88\x01\x01\x12\x33\n\x0e\x61pi_key_header\x18\x07 \x01(\tB\x08\xbaH\x05r\x03\x18\x80\x02H\x01R\x0c\x61piKeyHeader\x88\x01\x01\x12\x1d\n\x07\x65nabled\x18\x08 \x01(\x08H\x02R\x07\x65nabled\x88\x01\x01\x42\r\n\x0b_auth_valueB\x11\n\x0f_api_key_headerB\n\n\x08_enabled\"a\n\x1d\x43reateTelemetryConfigResponse\x12@\n\x06\x63onfig\x18\x01 \x01(\x0b\x32(.tars.admin.v1.TelemetryForwardingConfigR\x06\x63onfig\"\xcf\x01\n\x1bListTelemetryConfigsRequest\x12\x1c\n\x07user_id\x18\x01 \x01(\tH\x00R\x06userId\x88\x01\x01\x12H\n\x0etelemetry_type\x18\x02 \x01(\tB\x1c\xbaH\x19r\x17R\x06tracesR\x07metricsR\x04logsH\x01R\rtelemetryType\x88\x01\x01\x12\x1d\n\x07\x65nabled\x18\x03 \x01(\x08H\x02R\x07\x65nabled\x88\x01\x01\x42\n\n\x08_user_idB\x11\n\x0f_telemetry_typeB\n\n\x08_enabled\"x\n\x1cListTelemetryConfigsResponse\x12\x42\n\x07\x63onfigs\x18\x01 \x03(\x0b\x32(.tars.admin.v1.TelemetryForwardingConfigR\x07\x63onfigs\x12\x14\n\x05total\x18\x02 \x01(\x05R\x05total\"6\n\x19GetTelemetryConfigRequest\x12\x19\n\x02id\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18@R\x02id\"^\n\x1aGetTelemetryConfigResponse\x12@\n\x06\x63onfig\x18\x01 \x01(\x0b\x32(.tars.admin.v1.TelemetryForwardingConfigR\x06\x63onfig\"\x98\x04\n\x1cUpdateTelemetryConfigRequest\x12\x19\n\x02id\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18@R\x02id\x12(\n\x08sink_url\x18\x02 \x01(\tB\x08\xbaH\x05r\x03\x88\x01\x01H\x00R\x07sinkUrl\x88\x01\x01\x12\x46\n\x08protocol\x18\x03 \x01(\tB%\xbaH\"r R\x04grpcR\thttp/jsonR\rhttp/protobufH\x01R\x08protocol\x88\x01\x01\x12\x45\n\tauth_type\x18\x04 \x01(\tB#\xbaH r\x1eR\x04noneR\x06\x62\x65\x61rerR\x05\x62\x61sicR\x07\x61pi_keyH\x02R\x08\x61uthType\x88\x01\x01\x12\"\n\nauth_value\x18\x05 \x01(\tH\x03R\tauthValue\x88\x01\x01\x12\x33\n\x0e\x61pi_key_header\x18\x06 \x01(\tB\x08\xbaH\x05r\x03\x18\x80\x02H\x04R\x0c\x61piKeyHeader\x88\x01\x01\x12\x1d\n\x07\x65nabled\x18\x07 \x01(\x08H\x05R\x07\x65nabled\x88\x01\x01\x12K\n\x06status\x18\x08 \x01(\tB.\xbaH+r)R\tconnectedR\x0c\x64isconnectedR\x05\x65rrorR\x07testingH\x06R\x06status\x88\x01\x01\x42\x0b\n\t_sink_urlB\x0b\n\t_protocolB\x0c\n\n_auth_typeB\r\n\x0b_auth_valueB\x11\n\x0f_api_key_headerB\n\n\x08_enabledB\t\n\x07_status\"a\n\x1dUpdateTelemetryConfigResponse\x12@\n\x06\x63onfig\x18\x01 \x01(\x0b\x32(.tars.admin.v1.TelemetryForwardingConfigR\x06\x63onfig\"9\n\x1c\x44\x65leteTelemetryConfigRequest\x12\x19\n\x02id\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18@R\x02id\"9\n\x1d\x44\x65leteTelemetryConfigResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\"\xd1\x03\n\x08\x43ustomer\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1f\n\x0b\x63ustomer_id\x18\x02 \x01(\tR\ncustomerId\x12\x17\n\x04name\x18\x03 \x01(\tH\x00R\x04name\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x04 \x01(\tH\x01R\x0b\x64\x65scription\x88\x01\x01\x12;\n\x06labels\x18\x05 \x03(\x0b\x32#.tars.admin.v1.Customer.LabelsEntryR\x06labels\x12\x39\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x12>\n\ndeleted_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x02R\tdeletedAt\x88\x01\x01\x1a\x39\n\x0bLabelsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x07\n\x05_nameB\x0e\n\x0c_descriptionB\r\n\x0b_deleted_at\"\xd6\x02\n\x15\x43reateCustomerRequest\x12K\n\x0b\x63ustomer_id\x18\x01 \x01(\tB*\xbaH\'r%\x10\x01\x18?2\x1f^[a-z0-9]([a-z0-9-]*[a-z0-9])?$R\ncustomerId\x12!\n\x04name\x18\x02 \x01(\tB\x08\xbaH\x05r\x03\x18\xff\x01H\x00R\x04name\x88\x01\x01\x12/\n\x0b\x64\x65scription\x18\x03 \x01(\tB\x08\xbaH\x05r\x03\x18\xe8\x07H\x01R\x0b\x64\x65scription\x88\x01\x01\x12H\n\x06labels\x18\x04 \x03(\x0b\x32\x30.tars.admin.v1.CreateCustomerRequest.LabelsEntryR\x06labels\x1a\x39\n\x0bLabelsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x07\n\x05_nameB\x0e\n\x0c_description\"M\n\x16\x43reateCustomerResponse\x12\x33\n\x08\x63ustomer\x18\x01 \x01(\x0b\x32\x17.tars.admin.v1.CustomerR\x08\x63ustomer\"\x85\x01\n\x14ListCustomersRequest\x12,\n\tpage_size\x18\x01 \x01(\x05\x42\n\xbaH\x07\x1a\x05\x18\xe8\x07(\x00H\x00R\x08pageSize\x88\x01\x01\x12\"\n\npage_token\x18\x02 \x01(\tH\x01R\tpageToken\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_token\"v\n\x15ListCustomersResponse\x12\x35\n\tcustomers\x18\x01 \x03(\x0b\x32\x17.tars.admin.v1.CustomerR\tcustomers\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"@\n\x12GetCustomerRequest\x12*\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18?R\ncustomerId\"J\n\x13GetCustomerResponse\x12\x33\n\x08\x63ustomer\x18\x01 \x01(\x0b\x32\x17.tars.admin.v1.CustomerR\x08\x63ustomer\"\xb5\x02\n\x15UpdateCustomerRequest\x12*\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18?R\ncustomerId\x12!\n\x04name\x18\x02 \x01(\tB\x08\xbaH\x05r\x03\x18\xff\x01H\x00R\x04name\x88\x01\x01\x12/\n\x0b\x64\x65scription\x18\x03 \x01(\tB\x08\xbaH\x05r\x03\x18\xe8\x07H\x01R\x0b\x64\x65scription\x88\x01\x01\x12H\n\x06labels\x18\x04 \x03(\x0b\x32\x30.tars.admin.v1.UpdateCustomerRequest.LabelsEntryR\x06labels\x1a\x39\n\x0bLabelsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x07\n\x05_nameB\x0e\n\x0c_description\"M\n\x16UpdateCustomerResponse\x12\x33\n\x08\x63ustomer\x18\x01 \x01(\x0b\x32\x17.tars.admin.v1.CustomerR\x08\x63ustomer\"C\n\x15\x44\x65leteCustomerRequest\x12*\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18?R\ncustomerId\"m\n\x16\x44\x65leteCustomerResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12\x39\n\ndeleted_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tdeletedAt\"\xee\x03\n\x07Project\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1f\n\x0b\x63ustomer_id\x18\x02 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x03 \x01(\tR\tprojectId\x12\x17\n\x04name\x18\x04 \x01(\tH\x00R\x04name\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x05 \x01(\tH\x01R\x0b\x64\x65scription\x88\x01\x01\x12:\n\x06labels\x18\x06 \x03(\x0b\x32\".tars.admin.v1.Project.LabelsEntryR\x06labels\x12\x39\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x12>\n\ndeleted_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x02R\tdeletedAt\x88\x01\x01\x1a\x39\n\x0bLabelsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x07\n\x05_nameB\x0e\n\x0c_descriptionB\r\n\x0b_deleted_at\"\x81\x03\n\x14\x43reateProjectRequest\x12*\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18?R\ncustomerId\x12L\n\nproject_id\x18\x02 \x01(\tB-\xbaH*r(\x10\x01\x18\xfd\x01\x32!^[a-z0-9]([a-z0-9-_.]*[a-z0-9])?$R\tprojectId\x12!\n\x04name\x18\x03 \x01(\tB\x08\xbaH\x05r\x03\x18\xff\x01H\x00R\x04name\x88\x01\x01\x12/\n\x0b\x64\x65scription\x18\x04 \x01(\tB\x08\xbaH\x05r\x03\x18\xe8\x07H\x01R\x0b\x64\x65scription\x88\x01\x01\x12G\n\x06labels\x18\x05 \x03(\x0b\x32/.tars.admin.v1.CreateProjectRequest.LabelsEntryR\x06labels\x1a\x39\n\x0bLabelsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x07\n\x05_nameB\x0e\n\x0c_description\"I\n\x15\x43reateProjectResponse\x12\x30\n\x07project\x18\x01 \x01(\x0b\x32\x16.tars.admin.v1.ProjectR\x07project\"\xb0\x01\n\x13ListProjectsRequest\x12*\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18?R\ncustomerId\x12,\n\tpage_size\x18\x02 \x01(\x05\x42\n\xbaH\x07\x1a\x05\x18\xe8\x07(\x00H\x00R\x08pageSize\x88\x01\x01\x12\"\n\npage_token\x18\x03 \x01(\tH\x01R\tpageToken\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_token\"r\n\x14ListProjectsResponse\x12\x32\n\x08projects\x18\x01 \x03(\x0b\x32\x16.tars.admin.v1.ProjectR\x08projects\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"j\n\x11GetProjectRequest\x12*\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18?R\ncustomerId\x12)\n\nproject_id\x18\x02 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xfd\x01R\tprojectId\"F\n\x12GetProjectResponse\x12\x30\n\x07project\x18\x01 \x01(\x0b\x32\x16.tars.admin.v1.ProjectR\x07project\"\xde\x02\n\x14UpdateProjectRequest\x12*\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18?R\ncustomerId\x12)\n\nproject_id\x18\x02 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xfd\x01R\tprojectId\x12!\n\x04name\x18\x03 \x01(\tB\x08\xbaH\x05r\x03\x18\xff\x01H\x00R\x04name\x88\x01\x01\x12/\n\x0b\x64\x65scription\x18\x04 \x01(\tB\x08\xbaH\x05r\x03\x18\xe8\x07H\x01R\x0b\x64\x65scription\x88\x01\x01\x12G\n\x06labels\x18\x05 \x03(\x0b\x32/.tars.admin.v1.UpdateProjectRequest.LabelsEntryR\x06labels\x1a\x39\n\x0bLabelsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x07\n\x05_nameB\x0e\n\x0c_description\"I\n\x15UpdateProjectResponse\x12\x30\n\x07project\x18\x01 \x01(\x0b\x32\x16.tars.admin.v1.ProjectR\x07project\"m\n\x14\x44\x65leteProjectRequest\x12*\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18?R\ncustomerId\x12)\n\nproject_id\x18\x02 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xfd\x01R\tprojectId\"l\n\x15\x44\x65leteProjectResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12\x39\n\ndeleted_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tdeletedAt\"\x82\x02\n\rProjectMember\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1f\n\x0b\x63ustomer_id\x18\x02 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x03 \x01(\tR\tprojectId\x12\x17\n\x07user_id\x18\x04 \x01(\tR\x06userId\x12\x12\n\x04role\x18\x05 \x01(\tR\x04role\x12\x39\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\"\xbf\x01\n\x17\x41\x64\x64ProjectMemberRequest\x12*\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18?R\ncustomerId\x12)\n\nproject_id\x18\x02 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xfd\x01R\tprojectId\x12#\n\x07user_id\x18\x03 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xff\x01R\x06userId\x12(\n\x04role\x18\x04 \x01(\tB\x14\xbaH\x11r\x0fR\x05\x61\x64minR\x06memberR\x04role\"P\n\x18\x41\x64\x64ProjectMemberResponse\x12\x34\n\x06member\x18\x01 \x01(\x0b\x32\x1c.tars.admin.v1.ProjectMemberR\x06member\"r\n\x19ListProjectMembersRequest\x12*\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18?R\ncustomerId\x12)\n\nproject_id\x18\x02 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xfd\x01R\tprojectId\"T\n\x1aListProjectMembersResponse\x12\x36\n\x07members\x18\x01 \x03(\x0b\x32\x1c.tars.admin.v1.ProjectMemberR\x07members\"\xc2\x01\n\x1aUpdateProjectMemberRequest\x12*\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18?R\ncustomerId\x12)\n\nproject_id\x18\x02 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xfd\x01R\tprojectId\x12#\n\x07user_id\x18\x03 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xff\x01R\x06userId\x12(\n\x04role\x18\x04 \x01(\tB\x14\xbaH\x11r\x0fR\x05\x61\x64minR\x06memberR\x04role\"S\n\x1bUpdateProjectMemberResponse\x12\x34\n\x06member\x18\x01 \x01(\x0b\x32\x1c.tars.admin.v1.ProjectMemberR\x06member\"\x98\x01\n\x1aRemoveProjectMemberRequest\x12*\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18?R\ncustomerId\x12)\n\nproject_id\x18\x02 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xfd\x01R\tprojectId\x12#\n\x07user_id\x18\x03 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xff\x01R\x06userId\"7\n\x1bRemoveProjectMemberResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\"\xc7\x02\n\x07\x41IModel\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x14\n\x05model\x18\x02 \x01(\tR\x05model\x12\x1a\n\x08provider\x18\x03 \x01(\tR\x08provider\x12\x17\n\x04mode\x18\x04 \x01(\tH\x00R\x04mode\x88\x01\x01\x12\x1d\n\nis_enabled\x18\x05 \x01(\x08R\tisEnabled\x12\x35\n\x17input_price_per_million\x18\x06 \x01(\x01R\x14inputPricePerMillion\x12\x37\n\x18output_price_per_million\x18\x07 \x01(\x01R\x15outputPricePerMillion\x12%\n\x0e\x63ontext_window\x18\x08 \x01(\x05R\rcontextWindow\x12\"\n\x0c\x63\x61pabilities\x18\t \x03(\tR\x0c\x63\x61pabilitiesB\x07\n\x05_mode\"6\n\x11ListModelsRequest\x12!\n\x0conly_enabled\x18\x01 \x01(\x08R\x0bonlyEnabled\"D\n\x12ListModelsResponse\x12.\n\x06models\x18\x01 \x03(\x0b\x32\x16.tars.admin.v1.AIModelR\x06models\"s\n\x0fGetModelRequest\x12`\n\x08model_id\x18\x01 \x01(\tBE\xbaHBr@2>^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$R\x07modelId\"@\n\x10GetModelResponse\x12,\n\x05model\x18\x01 \x01(\x0b\x32\x16.tars.admin.v1.AIModelR\x05model\"\xe7\x01\n\x11ProjectModelEntry\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1f\n\x0b\x63ustomer_id\x18\x02 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x03 \x01(\tR\tprojectId\x12\x19\n\x08model_id\x18\x04 \x01(\tR\x07modelId\x12,\n\x05model\x18\x05 \x01(\x0b\x32\x16.tars.admin.v1.AIModelR\x05model\x12\x39\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\"\xd1\x01\n\x16\x41\x64\x64ProjectModelRequest\x12*\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18?R\ncustomerId\x12)\n\nproject_id\x18\x02 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xfd\x01R\tprojectId\x12`\n\x08model_id\x18\x03 \x01(\tBE\xbaHBr@2>^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$R\x07modelId\"Q\n\x17\x41\x64\x64ProjectModelResponse\x12\x36\n\x05\x65ntry\x18\x01 \x01(\x0b\x32 .tars.admin.v1.ProjectModelEntryR\x05\x65ntry\"q\n\x18ListProjectModelsRequest\x12*\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18?R\ncustomerId\x12)\n\nproject_id\x18\x02 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xfd\x01R\tprojectId\"W\n\x19ListProjectModelsResponse\x12:\n\x07\x65ntries\x18\x01 \x03(\x0b\x32 .tars.admin.v1.ProjectModelEntryR\x07\x65ntries\"\xd4\x01\n\x19RemoveProjectModelRequest\x12*\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18?R\ncustomerId\x12)\n\nproject_id\x18\x02 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xfd\x01R\tprojectId\x12`\n\x08model_id\x18\x03 \x01(\tBE\xbaHBr@2>^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$R\x07modelId\"6\n\x1aRemoveProjectModelResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\"\xc6\x01\n\x14ProjectProviderEntry\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1f\n\x0b\x63ustomer_id\x18\x02 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x03 \x01(\tR\tprojectId\x12#\n\rprovider_name\x18\x04 \x01(\tR\x0cproviderName\x12\x39\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\"\xa2\x01\n\x19\x41\x64\x64ProjectProviderRequest\x12*\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18?R\ncustomerId\x12)\n\nproject_id\x18\x02 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xfd\x01R\tprojectId\x12.\n\rprovider_name\x18\x03 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18?R\x0cproviderName\"W\n\x1a\x41\x64\x64ProjectProviderResponse\x12\x39\n\x05\x65ntry\x18\x01 \x01(\x0b\x32#.tars.admin.v1.ProjectProviderEntryR\x05\x65ntry\"t\n\x1bListProjectProvidersRequest\x12*\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18?R\ncustomerId\x12)\n\nproject_id\x18\x02 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xfd\x01R\tprojectId\"]\n\x1cListProjectProvidersResponse\x12=\n\x07\x65ntries\x18\x01 \x03(\x0b\x32#.tars.admin.v1.ProjectProviderEntryR\x07\x65ntries\"\xa5\x01\n\x1cRemoveProjectProviderRequest\x12*\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18?R\ncustomerId\x12)\n\nproject_id\x18\x02 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xfd\x01R\tprojectId\x12.\n\rprovider_name\x18\x03 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18?R\x0cproviderName\"9\n\x1dRemoveProjectProviderResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\"\xbf\x01\n\x15ProjectMcpServerEntry\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1f\n\x0b\x63ustomer_id\x18\x02 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x03 \x01(\tR\tprojectId\x12\x1b\n\tserver_id\x18\x04 \x01(\tR\x08serverId\x12\x39\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\"\xc8\x01\n\x1a\x41\x64\x64ProjectMcpServerRequest\x12*\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18?R\ncustomerId\x12)\n\nproject_id\x18\x02 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xfd\x01R\tprojectId\x12S\n\tserver_id\x18\x03 \x01(\tB6\xbaH3r1\x10\x01\x18\xfd\x01\x32*^[a-zA-Z0-9]([a-zA-Z0-9._-]*[a-zA-Z0-9])?$R\x08serverId\"Y\n\x1b\x41\x64\x64ProjectMcpServerResponse\x12:\n\x05\x65ntry\x18\x01 \x01(\x0b\x32$.tars.admin.v1.ProjectMcpServerEntryR\x05\x65ntry\"u\n\x1cListProjectMcpServersRequest\x12*\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18?R\ncustomerId\x12)\n\nproject_id\x18\x02 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xfd\x01R\tprojectId\"_\n\x1dListProjectMcpServersResponse\x12>\n\x07\x65ntries\x18\x01 \x03(\x0b\x32$.tars.admin.v1.ProjectMcpServerEntryR\x07\x65ntries\"\xcb\x01\n\x1dRemoveProjectMcpServerRequest\x12*\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18?R\ncustomerId\x12)\n\nproject_id\x18\x02 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xfd\x01R\tprojectId\x12S\n\tserver_id\x18\x03 \x01(\tB6\xbaH3r1\x10\x01\x18\xfd\x01\x32*^[a-zA-Z0-9]([a-zA-Z0-9._-]*[a-zA-Z0-9])?$R\x08serverId\":\n\x1eRemoveProjectMcpServerResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\"\x93\x01\n\x0eProjectSetting\x12!\n\x0csetting_name\x18\x01 \x01(\tR\x0bsettingName\x12#\n\rsetting_value\x18\x02 \x01(\tR\x0csettingValue\x12\x39\n\nupdated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\"r\n\x19GetProjectSettingsRequest\x12*\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18?R\ncustomerId\x12)\n\nproject_id\x18\x02 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xfd\x01R\tprojectId\"W\n\x1aGetProjectSettingsResponse\x12\x39\n\x08settings\x18\x01 \x03(\x0b\x32\x1d.tars.admin.v1.ProjectSettingR\x08settings\"\xec\x01\n\x1bUpsertProjectSettingRequest\x12*\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18?R\ncustomerId\x12)\n\nproject_id\x18\x02 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xfd\x01R\tprojectId\x12\x45\n\x0csetting_name\x18\x03 \x01(\tB\"\xbaH\x1fr\x1dR\x0fglobal-fallbackR\nrate-limitR\x0bsettingName\x12/\n\rsetting_value\x18\x04 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\x80\x08R\x0csettingValue\"W\n\x1cUpsertProjectSettingResponse\x12\x37\n\x07setting\x18\x01 \x01(\x0b\x32\x1d.tars.admin.v1.ProjectSettingR\x07setting\"\xbb\x01\n\x1b\x44\x65leteProjectSettingRequest\x12*\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18?R\ncustomerId\x12)\n\nproject_id\x18\x02 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xfd\x01R\tprojectId\x12\x45\n\x0csetting_name\x18\x03 \x01(\tB\"\xbaH\x1fr\x1dR\x0fglobal-fallbackR\nrate-limitR\x0bsettingName\"8\n\x1c\x44\x65leteProjectSettingResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success*\xa9\x01\n\x14ServiceAccountStatus\x12&\n\"SERVICE_ACCOUNT_STATUS_UNSPECIFIED\x10\x00\x12!\n\x1dSERVICE_ACCOUNT_STATUS_ACTIVE\x10\x01\x12\"\n\x1eSERVICE_ACCOUNT_STATUS_REVOKED\x10\x02\x12\"\n\x1eSERVICE_ACCOUNT_STATUS_EXPIRED\x10\x03*\x90\x01\n\x0fUserTokenStatus\x12!\n\x1dUSER_TOKEN_STATUS_UNSPECIFIED\x10\x00\x12\x1c\n\x18USER_TOKEN_STATUS_ACTIVE\x10\x01\x12\x1d\n\x19USER_TOKEN_STATUS_REVOKED\x10\x02\x12\x1d\n\x19USER_TOKEN_STATUS_EXPIRED\x10\x03\x32\xb9I\n\x0c\x41\x64minService\x12h\n\x04Ping\x12\x1a.tars.admin.v1.PingRequest\x1a\x1b.tars.admin.v1.PingResponse\"\'\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\x82\xd3\xe4\x93\x02\x10\x12\x0e/admin/v1/ping\x12\x9d\x01\n\x0f\x43reateWorkspace\x12%.tars.admin.v1.CreateWorkspaceRequest\x1a&.tars.admin.v1.CreateWorkspaceResponse\";\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\nWorkspaces\x82\xd3\xe4\x93\x02\x19\"\x14/admin/v1/workspaces:\x01*\x12\x9a\x01\n\x0eListWorkspaces\x12$.tars.admin.v1.ListWorkspacesRequest\x1a%.tars.admin.v1.ListWorkspacesResponse\";\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\nWorkspaces\x82\xd3\xe4\x93\x02\x16\x12\x14/admin/v1/workspaces\x12\x99\x01\n\x0cGetWorkspace\x12\".tars.admin.v1.GetWorkspaceRequest\x1a#.tars.admin.v1.GetWorkspaceResponse\"@\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\nWorkspaces\x82\xd3\xe4\x93\x02\x1b\x12\x19/admin/v1/workspaces/{id}\x12\xa2\x01\n\x0fUpdateWorkspace\x12%.tars.admin.v1.UpdateWorkspaceRequest\x1a&.tars.admin.v1.UpdateWorkspaceResponse\"@\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\nWorkspaces\x82\xd3\xe4\x93\x02\x1e\x32\x19/admin/v1/workspaces/{id}:\x01*\x12\xa6\x01\n\x0fSetWorkspaceURL\x12%.tars.admin.v1.SetWorkspaceURLRequest\x1a&.tars.admin.v1.SetWorkspaceURLResponse\"D\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\nWorkspaces\x82\xd3\xe4\x93\x02\"\"\x1d/admin/v1/workspaces/{id}/url:\x01*\x12\xb6\x01\n\x13SetWorkspaceProject\x12).tars.admin.v1.SetWorkspaceProjectRequest\x1a*.tars.admin.v1.SetWorkspaceProjectResponse\"H\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\nWorkspaces\x82\xd3\xe4\x93\x02&\"!/admin/v1/workspaces/{id}/project:\x01*\x12\x9f\x01\n\x0f\x44\x65leteWorkspace\x12%.tars.admin.v1.DeleteWorkspaceRequest\x1a&.tars.admin.v1.DeleteWorkspaceResponse\"=\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\nWorkspaces\x82\xd3\xe4\x93\x02\x1b*\x19/admin/v1/workspaces/{id}\x12\xb8\x01\n\x14\x43reateServiceAccount\x12*.tars.admin.v1.CreateServiceAccountRequest\x1a+.tars.admin.v1.CreateServiceAccountResponse\"G\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x10Service Accounts\x82\xd3\xe4\x93\x02\x1f\"\x1a/admin/v1/service-accounts:\x01*\x12\xb5\x01\n\x13ListServiceAccounts\x12).tars.admin.v1.ListServiceAccountsRequest\x1a*.tars.admin.v1.ListServiceAccountsResponse\"G\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x10Service Accounts\x82\xd3\xe4\x93\x02\x1c\x12\x1a/admin/v1/service-accounts\x12\xb4\x01\n\x11GetServiceAccount\x12\'.tars.admin.v1.GetServiceAccountRequest\x1a(.tars.admin.v1.GetServiceAccountResponse\"L\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x10Service Accounts\x82\xd3\xe4\x93\x02!\x12\x1f/admin/v1/service-accounts/{id}\x12\xc4\x01\n\x14RevokeServiceAccount\x12*.tars.admin.v1.RevokeServiceAccountRequest\x1a+.tars.admin.v1.RevokeServiceAccountResponse\"S\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x10Service Accounts\x82\xd3\xe4\x93\x02+\"&/admin/v1/service-accounts/{id}:revoke:\x01*\x12\xc8\x01\n\x15RestoreServiceAccount\x12+.tars.admin.v1.RestoreServiceAccountRequest\x1a,.tars.admin.v1.RestoreServiceAccountResponse\"T\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x10Service Accounts\x82\xd3\xe4\x93\x02,\"\'/admin/v1/service-accounts/{id}:restore:\x01*\x12\x9f\x01\n\x0f\x43reateUserToken\x12%.tars.admin.v1.CreateUserTokenRequest\x1a&.tars.admin.v1.CreateUserTokenResponse\"=\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x0bUser Tokens\x82\xd3\xe4\x93\x02\x1a\"\x15/admin/v1/user-tokens:\x01*\x12\x9c\x01\n\x0eListUserTokens\x12$.tars.admin.v1.ListUserTokensRequest\x1a%.tars.admin.v1.ListUserTokensResponse\"=\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x0bUser Tokens\x82\xd3\xe4\x93\x02\x17\x12\x15/admin/v1/user-tokens\x12\x9c\x01\n\x0cGetUserToken\x12\".tars.admin.v1.GetUserTokenRequest\x1a#.tars.admin.v1.GetUserTokenResponse\"C\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x0bUser Tokens\x82\xd3\xe4\x93\x02\x1d\x12\x1b/admin/v1/user-tokens/{jti}\x12\xac\x01\n\x0fRevokeUserToken\x12%.tars.admin.v1.RevokeUserTokenRequest\x1a&.tars.admin.v1.RevokeUserTokenResponse\"J\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x0bUser Tokens\x82\xd3\xe4\x93\x02\'\"\"/admin/v1/user-tokens/{jti}:revoke:\x01*\x12\xb5\x01\n\x15\x43reateTelemetryConfig\x12+.tars.admin.v1.CreateTelemetryConfigRequest\x1a,.tars.admin.v1.CreateTelemetryConfigResponse\"A\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\tTelemetry\x82\xd3\xe4\x93\x02 \"\x1b/admin/v1/telemetry-configs:\x01*\x12\xb2\x01\n\x14ListTelemetryConfigs\x12*.tars.admin.v1.ListTelemetryConfigsRequest\x1a+.tars.admin.v1.ListTelemetryConfigsResponse\"A\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\tTelemetry\x82\xd3\xe4\x93\x02\x1d\x12\x1b/admin/v1/telemetry-configs\x12\xb1\x01\n\x12GetTelemetryConfig\x12(.tars.admin.v1.GetTelemetryConfigRequest\x1a).tars.admin.v1.GetTelemetryConfigResponse\"F\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\tTelemetry\x82\xd3\xe4\x93\x02\"\x12 /admin/v1/telemetry-configs/{id}\x12\xba\x01\n\x15UpdateTelemetryConfig\x12+.tars.admin.v1.UpdateTelemetryConfigRequest\x1a,.tars.admin.v1.UpdateTelemetryConfigResponse\"F\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\tTelemetry\x82\xd3\xe4\x93\x02%2 /admin/v1/telemetry-configs/{id}:\x01*\x12\xb7\x01\n\x15\x44\x65leteTelemetryConfig\x12+.tars.admin.v1.DeleteTelemetryConfigRequest\x1a,.tars.admin.v1.DeleteTelemetryConfigResponse\"C\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\tTelemetry\x82\xd3\xe4\x93\x02\"* /admin/v1/telemetry-configs/{id}\x12\x98\x01\n\x0e\x43reateCustomer\x12$.tars.admin.v1.CreateCustomerRequest\x1a%.tars.admin.v1.CreateCustomerResponse\"9\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\tCustomers\x82\xd3\xe4\x93\x02\x18\"\x13/admin/v1/customers:\x01*\x12\x95\x01\n\rListCustomers\x12#.tars.admin.v1.ListCustomersRequest\x1a$.tars.admin.v1.ListCustomersResponse\"9\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\tCustomers\x82\xd3\xe4\x93\x02\x15\x12\x13/admin/v1/customers\x12\x9d\x01\n\x0bGetCustomer\x12!.tars.admin.v1.GetCustomerRequest\x1a\".tars.admin.v1.GetCustomerResponse\"G\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\tCustomers\x82\xd3\xe4\x93\x02#\x12!/admin/v1/customers/{customer_id}\x12\xa6\x01\n\x0eUpdateCustomer\x12$.tars.admin.v1.UpdateCustomerRequest\x1a%.tars.admin.v1.UpdateCustomerResponse\"G\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\tCustomers\x82\xd3\xe4\x93\x02&2!/admin/v1/customers/{customer_id}:\x01*\x12\xa3\x01\n\x0e\x44\x65leteCustomer\x12$.tars.admin.v1.DeleteCustomerRequest\x1a%.tars.admin.v1.DeleteCustomerResponse\"D\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\tCustomers\x82\xd3\xe4\x93\x02#*!/admin/v1/customers/{customer_id}\x12\xab\x01\n\rCreateProject\x12#.tars.admin.v1.CreateProjectRequest\x1a$.tars.admin.v1.CreateProjectResponse\"O\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x08Projects\x82\xd3\xe4\x93\x02/\"*/admin/v1/customers/{customer_id}/projects:\x01*\x12\xa8\x01\n\x0cListProjects\x12\".tars.admin.v1.ListProjectsRequest\x1a#.tars.admin.v1.ListProjectsResponse\"O\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x08Projects\x82\xd3\xe4\x93\x02,\x12*/admin/v1/customers/{customer_id}/projects\x12\xaf\x01\n\nGetProject\x12 .tars.admin.v1.GetProjectRequest\x1a!.tars.admin.v1.GetProjectResponse\"\\\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x08Projects\x82\xd3\xe4\x93\x02\x39\x12\x37/admin/v1/customers/{customer_id}/projects/{project_id}\x12\xb8\x01\n\rUpdateProject\x12#.tars.admin.v1.UpdateProjectRequest\x1a$.tars.admin.v1.UpdateProjectResponse\"\\\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x08Projects\x82\xd3\xe4\x93\x02<27/admin/v1/customers/{customer_id}/projects/{project_id}:\x01*\x12\xb5\x01\n\rDeleteProject\x12#.tars.admin.v1.DeleteProjectRequest\x1a$.tars.admin.v1.DeleteProjectResponse\"Y\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x08Projects\x82\xd3\xe4\x93\x02\x39*7/admin/v1/customers/{customer_id}/projects/{project_id}\x12\xd0\x01\n\x10\x41\x64\x64ProjectMember\x12&.tars.admin.v1.AddProjectMemberRequest\x1a\'.tars.admin.v1.AddProjectMemberResponse\"k\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x0fProject Members\x82\xd3\xe4\x93\x02\x44\"?/admin/v1/customers/{customer_id}/projects/{project_id}/members:\x01*\x12\xd6\x01\n\x12ListProjectMembers\x12(.tars.admin.v1.ListProjectMembersRequest\x1a).tars.admin.v1.ListProjectMembersResponse\"k\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x0fProject Members\x82\xd3\xe4\x93\x02\x41\x12?/admin/v1/customers/{customer_id}/projects/{project_id}/members\x12\xe3\x01\n\x13UpdateProjectMember\x12).tars.admin.v1.UpdateProjectMemberRequest\x1a*.tars.admin.v1.UpdateProjectMemberResponse\"u\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x0fProject Members\x82\xd3\xe4\x93\x02N2I/admin/v1/customers/{customer_id}/projects/{project_id}/members/{user_id}:\x01*\x12\xe0\x01\n\x13RemoveProjectMember\x12).tars.admin.v1.RemoveProjectMemberRequest\x1a*.tars.admin.v1.RemoveProjectMemberResponse\"r\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x0fProject Members\x82\xd3\xe4\x93\x02K*I/admin/v1/customers/{customer_id}/projects/{project_id}/members/{user_id}\x12\x86\x01\n\nListModels\x12 .tars.admin.v1.ListModelsRequest\x1a!.tars.admin.v1.ListModelsResponse\"3\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x06Models\x82\xd3\xe4\x93\x02\x12\x12\x10/admin/v1/models\x12\x8b\x01\n\x08GetModel\x12\x1e.tars.admin.v1.GetModelRequest\x1a\x1f.tars.admin.v1.GetModelResponse\">\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x06Models\x82\xd3\xe4\x93\x02\x1d\x12\x1b/admin/v1/models/{model_id}\x12\xcb\x01\n\x0f\x41\x64\x64ProjectModel\x12%.tars.admin.v1.AddProjectModelRequest\x1a&.tars.admin.v1.AddProjectModelResponse\"i\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x0eProject Models\x82\xd3\xe4\x93\x02\x43\">/admin/v1/customers/{customer_id}/projects/{project_id}/models:\x01*\x12\xd1\x01\n\x11ListProjectModels\x12\'.tars.admin.v1.ListProjectModelsRequest\x1a(.tars.admin.v1.ListProjectModelsResponse\"i\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x0eProject Models\x82\xd3\xe4\x93\x02@\x12>/admin/v1/customers/{customer_id}/projects/{project_id}/models\x12\xdc\x01\n\x12RemoveProjectModel\x12(.tars.admin.v1.RemoveProjectModelRequest\x1a).tars.admin.v1.RemoveProjectModelResponse\"q\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x0eProject Models\x82\xd3\xe4\x93\x02K*I/admin/v1/customers/{customer_id}/projects/{project_id}/models/{model_id}\x12\xda\x01\n\x12\x41\x64\x64ProjectProvider\x12(.tars.admin.v1.AddProjectProviderRequest\x1a).tars.admin.v1.AddProjectProviderResponse\"o\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x11Project Providers\x82\xd3\xe4\x93\x02\x46\"A/admin/v1/customers/{customer_id}/projects/{project_id}/providers:\x01*\x12\xe0\x01\n\x14ListProjectProviders\x12*.tars.admin.v1.ListProjectProvidersRequest\x1a+.tars.admin.v1.ListProjectProvidersResponse\"o\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x11Project Providers\x82\xd3\xe4\x93\x02\x43\x12\x41/admin/v1/customers/{customer_id}/projects/{project_id}/providers\x12\xf0\x01\n\x15RemoveProjectProvider\x12+.tars.admin.v1.RemoveProjectProviderRequest\x1a,.tars.admin.v1.RemoveProjectProviderResponse\"|\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x11Project Providers\x82\xd3\xe4\x93\x02S*Q/admin/v1/customers/{customer_id}/projects/{project_id}/providers/{provider_name}\x12\xe1\x01\n\x13\x41\x64\x64ProjectMcpServer\x12).tars.admin.v1.AddProjectMcpServerRequest\x1a*.tars.admin.v1.AddProjectMcpServerResponse\"s\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x13Project MCP Servers\x82\xd3\xe4\x93\x02H\"C/admin/v1/customers/{customer_id}/projects/{project_id}/mcp-servers:\x01*\x12\xe7\x01\n\x15ListProjectMcpServers\x12+.tars.admin.v1.ListProjectMcpServersRequest\x1a,.tars.admin.v1.ListProjectMcpServersResponse\"s\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x13Project MCP Servers\x82\xd3\xe4\x93\x02\x45\x12\x43/admin/v1/customers/{customer_id}/projects/{project_id}/mcp-servers\x12\xf3\x01\n\x16RemoveProjectMcpServer\x12,.tars.admin.v1.RemoveProjectMcpServerRequest\x1a-.tars.admin.v1.RemoveProjectMcpServerResponse\"|\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x13Project MCP Servers\x82\xd3\xe4\x93\x02Q*O/admin/v1/customers/{customer_id}/projects/{project_id}/mcp-servers/{server_id}\x12\xd8\x01\n\x12GetProjectSettings\x12(.tars.admin.v1.GetProjectSettingsRequest\x1a).tars.admin.v1.GetProjectSettingsResponse\"m\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x10Project Settings\x82\xd3\xe4\x93\x02\x42\x12@/admin/v1/customers/{customer_id}/projects/{project_id}/settings\x12\xed\x01\n\x14UpsertProjectSetting\x12*.tars.admin.v1.UpsertProjectSettingRequest\x1a+.tars.admin.v1.UpsertProjectSettingResponse\"|\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x10Project Settings\x82\xd3\xe4\x93\x02T\x1aO/admin/v1/customers/{customer_id}/projects/{project_id}/settings/{setting_name}:\x01*\x12\xea\x01\n\x14\x44\x65leteProjectSetting\x12*.tars.admin.v1.DeleteProjectSettingRequest\x1a+.tars.admin.v1.DeleteProjectSettingResponse\"y\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x10Project Settings\x82\xd3\xe4\x93\x02Q*O/admin/v1/customers/{customer_id}/projects/{project_id}/settings/{setting_name}Bu\n\x11\x63om.tars.admin.v1B\nAdminProtoP\x01\xa2\x02\x03TAX\xaa\x02\rTars.Admin.V1\xca\x02\rTars\\Admin\\V1\xe2\x02\x19Tars\\Admin\\V1\\GPBMetadata\xea\x02\x0fTars::Admin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.admin.v1.admin_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\021com.tars.admin.v1B\nAdminProtoP\001\242\002\003TAX\252\002\rTars.Admin.V1\312\002\rTars\\Admin\\V1\342\002\031Tars\\Admin\\V1\\GPBMetadata\352\002\017Tars::Admin::V1'
  _globals['_CREATEWORKSPACEREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEWORKSPACEREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEWORKSPACEREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_CREATEWORKSPACEREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H\'r%\020\001\030?2\037^[a-z0-9]([a-z0-9-]*[a-z0-9])?$'
  _globals['_CREATEWORKSPACEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_CREATEWORKSPACEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\272H\032r\030\020\001\030\375\0012\021^[a-zA-Z0-9-_.]+$'
  _globals['_CREATEWORKSPACEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEWORKSPACEREQUEST'].fields_by_name['name']._serialized_options = b'\272H\005r\003\030\377\001'
  _globals['_CREATEWORKSPACEREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEWORKSPACEREQUEST'].fields_by_name['description']._serialized_options = b'\272H\005r\003\030\350\007'
  _globals['_CREATEWORKSPACEREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATEWORKSPACEREQUEST'].fields_by_name['labels']._serialized_options = b'\272H5\232\0012\0202\"\'r%\030?2!^[a-z0-9]([a-z0-9-_.]*[a-z0-9])?$*\005r\003\030\377\001'
  _globals['_CREATEWORKSPACEREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_CREATEWORKSPACEREQUEST'].fields_by_name['project_id']._serialized_options = b'\272H\005r\003\030\375\001'
  _globals['_LISTWORKSPACESREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_LISTWORKSPACESREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H%r#\030?2\037^[a-z0-9]([a-z0-9-]*[a-z0-9])?$'
  _globals['_LISTWORKSPACESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTWORKSPACESREQUEST'].fields_by_name['page_size']._serialized_options = b'\272H\007\032\005\030\350\007(\000'
  _globals['_GETWORKSPACEREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GETWORKSPACEREQUEST'].fields_by_name['id']._serialized_options = b'\272HBr@2>^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$'
  _globals['_UPDATEWORKSPACEREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEWORKSPACEREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEWORKSPACEREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_UPDATEWORKSPACEREQUEST'].fields_by_name['id']._serialized_options = b'\272HBr@2>^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$'
  _globals['_UPDATEWORKSPACEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEWORKSPACEREQUEST'].fields_by_name['name']._serialized_options = b'\272H\005r\003\030\377\001'
  _globals['_UPDATEWORKSPACEREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEWORKSPACEREQUEST'].fields_by_name['description']._serialized_options = b'\272H\005r\003\030\350\007'
  _globals['_UPDATEWORKSPACEREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEWORKSPACEREQUEST'].fields_by_name['labels']._serialized_options = b'\272H5\232\0012\0202\"\'r%\030?2!^[a-z0-9]([a-z0-9-_.]*[a-z0-9])?$*\005r\003\030\377\001'
  _globals['_SETWORKSPACEPROJECTREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_SETWORKSPACEPROJECTREQUEST'].fields_by_name['id']._serialized_options = b'\272HBr@2>^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$'
  _globals['_SETWORKSPACEPROJECTREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_SETWORKSPACEPROJECTREQUEST'].fields_by_name['project_id']._serialized_options = b'\272H\005r\003\030\377\001'
  _globals['_SETWORKSPACEURLREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_SETWORKSPACEURLREQUEST'].fields_by_name['id']._serialized_options = b'\272HBr@2>^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$'
  _globals['_SETWORKSPACEURLREQUEST'].fields_by_name['url']._loaded_options = None
  _globals['_SETWORKSPACEURLREQUEST'].fields_by_name['url']._serialized_options = b'\272H\007r\005\020\001\030\200\020'
  _globals['_DELETEWORKSPACEREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_DELETEWORKSPACEREQUEST'].fields_by_name['id']._serialized_options = b'\272HBr@2>^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$'
  _globals['_WORKSPACE_LABELSENTRY']._loaded_options = None
  _globals['_WORKSPACE_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATESERVICEACCOUNTREQUEST_TELEMETRYHEADERSENTRY']._loaded_options = None
  _globals['_CREATESERVICEACCOUNTREQUEST_TELEMETRYHEADERSENTRY']._serialized_options = b'8\001'
  _globals['_CREATESERVICEACCOUNTREQUEST_TELEMETRYLOCALVARSENTRY']._loaded_options = None
  _globals['_CREATESERVICEACCOUNTREQUEST_TELEMETRYLOCALVARSENTRY']._serialized_options = b'8\001'
  _globals['_CREATESERVICEACCOUNTREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_CREATESERVICEACCOUNTREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H\'r%\020\001\030?2\037^[a-z0-9]([a-z0-9-]*[a-z0-9])?$'
  _globals['_CREATESERVICEACCOUNTREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_CREATESERVICEACCOUNTREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\272H\032r\030\020\001\030\375\0012\021^[a-zA-Z0-9-_.]+$'
  _globals['_CREATESERVICEACCOUNTREQUEST'].fields_by_name['validity_days']._loaded_options = None
  _globals['_CREATESERVICEACCOUNTREQUEST'].fields_by_name['validity_days']._serialized_options = b'\272H\007\"\005\030\302\034(\001'
  _globals['_CREATESERVICEACCOUNTREQUEST'].fields_by_name['api_uri']._loaded_options = None
  _globals['_CREATESERVICEACCOUNTREQUEST'].fields_by_name['api_uri']._serialized_options = b'\272H\005r\003\210\001\001'
  _globals['_CREATESERVICEACCOUNTREQUEST'].fields_by_name['serve_url']._loaded_options = None
  _globals['_CREATESERVICEACCOUNTREQUEST'].fields_by_name['serve_url']._serialized_options = b'\272H\005r\003\210\001\001'
  _globals['_CREATESERVICEACCOUNTREQUEST'].fields_by_name['issuer']._loaded_options = None
  _globals['_CREATESERVICEACCOUNTREQUEST'].fields_by_name['issuer']._serialized_options = b'\272H\005r\003\210\001\001'
  _globals['_CREATESERVICEACCOUNTREQUEST'].fields_by_name['audience']._loaded_options = None
  _globals['_CREATESERVICEACCOUNTREQUEST'].fields_by_name['audience']._serialized_options = b'\272H\030r\026\030\375\0012\021^[a-zA-Z0-9._-]+$'
  _globals['_CREATESERVICEACCOUNTREQUEST'].fields_by_name['jwks_uri']._loaded_options = None
  _globals['_CREATESERVICEACCOUNTREQUEST'].fields_by_name['jwks_uri']._serialized_options = b'\272H\005r\003\210\001\001'
  _globals['_CREATESERVICEACCOUNTREQUEST'].fields_by_name['telemetry_protocol']._loaded_options = None
  _globals['_CREATESERVICEACCOUNTREQUEST'].fields_by_name['telemetry_protocol']._serialized_options = b'\272H$r\"R\000R\004grpcR\rhttp/protobufR\thttp/json'
  _globals['_CREATESERVICEACCOUNTREQUEST'].fields_by_name['telemetry_timeout']._loaded_options = None
  _globals['_CREATESERVICEACCOUNTREQUEST'].fields_by_name['telemetry_timeout']._serialized_options = b'\272H\034r\0322\030^[0-9]+(ns|us|ms|s|m|h)$'
  _globals['_CREATESERVICEACCOUNTREQUEST'].fields_by_name['scopes']._loaded_options = None
  _globals['_CREATESERVICEACCOUNTREQUEST'].fields_by_name['scopes']._serialized_options = b'\272H\030\222\001\025\010\000\020\n\"\017r\r\03022\t^[a-z_]+$'
  _globals['_CREATESERVICEACCOUNTREQUEST'].fields_by_name['router_url']._loaded_options = None
  _globals['_CREATESERVICEACCOUNTREQUEST'].fields_by_name['router_url']._serialized_options = b'\272H\005r\003\210\001\001'
  _globals['_ROUTERCONFIG'].fields_by_name['url']._loaded_options = None
  _globals['_ROUTERCONFIG'].fields_by_name['url']._serialized_options = b'\272H\005r\003\210\001\001'
  _globals['_TELEMETRYCONFIG_HEADERSENTRY']._loaded_options = None
  _globals['_TELEMETRYCONFIG_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_LISTSERVICEACCOUNTSREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_LISTSERVICEACCOUNTSREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H%r#\030?2\037^[a-z0-9]([a-z0-9-]*[a-z0-9])?$'
  _globals['_LISTSERVICEACCOUNTSREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_LISTSERVICEACCOUNTSREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\272H\030r\026\030\375\0012\021^[a-zA-Z0-9-_.]+$'
  _globals['_LISTSERVICEACCOUNTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTSERVICEACCOUNTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\272H\007\032\005\030\350\007(\000'
  _globals['_GETSERVICEACCOUNTREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GETSERVICEACCOUNTREQUEST'].fields_by_name['id']._serialized_options = b'\272HBr@2>^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$'
  _globals['_SERVICEACCOUNTINFO_METADATAENTRY']._loaded_options = None
  _globals['_SERVICEACCOUNTINFO_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_REVOKESERVICEACCOUNTREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_REVOKESERVICEACCOUNTREQUEST'].fields_by_name['id']._serialized_options = b'\272HBr@2>^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$'
  _globals['_REVOKESERVICEACCOUNTREQUEST'].fields_by_name['reason']._loaded_options = None
  _globals['_REVOKESERVICEACCOUNTREQUEST'].fields_by_name['reason']._serialized_options = b'\272H\005r\003\030\364\003'
  _globals['_RESTORESERVICEACCOUNTREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_RESTORESERVICEACCOUNTREQUEST'].fields_by_name['id']._serialized_options = b'\272HBr@2>^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$'
  _globals['_RESTORESERVICEACCOUNTREQUEST'].fields_by_name['reason']._loaded_options = None
  _globals['_RESTORESERVICEACCOUNTREQUEST'].fields_by_name['reason']._serialized_options = b'\272H\005r\003\030\364\003'
  _globals['_CREATEUSERTOKENREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_CREATEUSERTOKENREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H\025r\023\020\001\030d2\r^[a-z0-9_-]+$'
  _globals['_CREATEUSERTOKENREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_CREATEUSERTOKENREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\272H\025r\023\020\001\030d2\r^[a-z0-9_-]+$'
  _globals['_CREATEUSERTOKENREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_CREATEUSERTOKENREQUEST'].fields_by_name['user_id']._serialized_options = b'\272H\007r\005\020\001\030\377\001'
  _globals['_CREATEUSERTOKENREQUEST'].fields_by_name['role']._loaded_options = None
  _globals['_CREATEUSERTOKENREQUEST'].fields_by_name['role']._serialized_options = b'\272H\006r\004\020\001\030d'
  _globals['_CREATEUSERTOKENREQUEST'].fields_by_name['organization_unit']._loaded_options = None
  _globals['_CREATEUSERTOKENREQUEST'].fields_by_name['organization_unit']._serialized_options = b'\272H\007r\005\020\001\030\377\001'
  _globals['_CREATEUSERTOKENREQUEST'].fields_by_name['expires_in_days']._loaded_options = None
  _globals['_CREATEUSERTOKENREQUEST'].fields_by_name['expires_in_days']._serialized_options = b'\272H\007\"\005\030\355\002(\001'
  _globals['_CREATEUSERTOKENREQUEST'].fields_by_name['scopes']._loaded_options = None
  _globals['_CREATEUSERTOKENREQUEST'].fields_by_name['scopes']._serialized_options = b'\272H\030\222\001\025\010\000\020\n\"\017r\r\03022\t^[a-z_]+$'
  _globals['_CREATEUSERTOKENREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEUSERTOKENREQUEST'].fields_by_name['name']._serialized_options = b'\272H\005r\003\030\377\001'
  _globals['_IMPERSONATIONMETADATA_CONTEXTENTRY']._loaded_options = None
  _globals['_IMPERSONATIONMETADATA_CONTEXTENTRY']._serialized_options = b'8\001'
  _globals['_IMPERSONATIONMETADATA'].fields_by_name['impersonator_key']._loaded_options = None
  _globals['_IMPERSONATIONMETADATA'].fields_by_name['impersonator_key']._serialized_options = b'\272H\007r\005\020\001\030\377\001'
  _globals['_IMPERSONATIONMETADATA'].fields_by_name['reason']._loaded_options = None
  _globals['_IMPERSONATIONMETADATA'].fields_by_name['reason']._serialized_options = b'\272H\005r\003\030\364\003'
  _globals['_LISTUSERTOKENSREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_LISTUSERTOKENSREQUEST'].fields_by_name['user_id']._serialized_options = b'\272H\005r\003\030\377\001'
  _globals['_LISTUSERTOKENSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTUSERTOKENSREQUEST'].fields_by_name['page_size']._serialized_options = b'\272H\007\032\005\030\350\007(\000'
  _globals['_GETUSERTOKENREQUEST'].fields_by_name['jti']._loaded_options = None
  _globals['_GETUSERTOKENREQUEST'].fields_by_name['jti']._serialized_options = b'\272H\006r\004\020\001\030@'
  _globals['_REVOKEUSERTOKENREQUEST'].fields_by_name['jti']._loaded_options = None
  _globals['_REVOKEUSERTOKENREQUEST'].fields_by_name['jti']._serialized_options = b'\272H\006r\004\020\001\030@'
  _globals['_REVOKEUSERTOKENREQUEST'].fields_by_name['reason']._loaded_options = None
  _globals['_REVOKEUSERTOKENREQUEST'].fields_by_name['reason']._serialized_options = b'\272H\005r\003\030\364\003'
  _globals['_CREATETELEMETRYCONFIGREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_CREATETELEMETRYCONFIGREQUEST'].fields_by_name['user_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_CREATETELEMETRYCONFIGREQUEST'].fields_by_name['telemetry_type']._loaded_options = None
  _globals['_CREATETELEMETRYCONFIGREQUEST'].fields_by_name['telemetry_type']._serialized_options = b'\272H\031r\027R\006tracesR\007metricsR\004logs'
  _globals['_CREATETELEMETRYCONFIGREQUEST'].fields_by_name['sink_url']._loaded_options = None
  _globals['_CREATETELEMETRYCONFIGREQUEST'].fields_by_name['sink_url']._serialized_options = b'\272H\007r\005\020\001\210\001\001'
  _globals['_CREATETELEMETRYCONFIGREQUEST'].fields_by_name['protocol']._loaded_options = None
  _globals['_CREATETELEMETRYCONFIGREQUEST'].fields_by_name['protocol']._serialized_options = b'\272H\"r R\004grpcR\thttp/jsonR\rhttp/protobuf'
  _globals['_CREATETELEMETRYCONFIGREQUEST'].fields_by_name['auth_type']._loaded_options = None
  _globals['_CREATETELEMETRYCONFIGREQUEST'].fields_by_name['auth_type']._serialized_options = b'\272H r\036R\004noneR\006bearerR\005basicR\007api_key'
  _globals['_CREATETELEMETRYCONFIGREQUEST'].fields_by_name['api_key_header']._loaded_options = None
  _globals['_CREATETELEMETRYCONFIGREQUEST'].fields_by_name['api_key_header']._serialized_options = b'\272H\005r\003\030\200\002'
  _globals['_LISTTELEMETRYCONFIGSREQUEST'].fields_by_name['telemetry_type']._loaded_options = None
  _globals['_LISTTELEMETRYCONFIGSREQUEST'].fields_by_name['telemetry_type']._serialized_options = b'\272H\031r\027R\006tracesR\007metricsR\004logs'
  _globals['_GETTELEMETRYCONFIGREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GETTELEMETRYCONFIGREQUEST'].fields_by_name['id']._serialized_options = b'\272H\006r\004\020\001\030@'
  _globals['_UPDATETELEMETRYCONFIGREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_UPDATETELEMETRYCONFIGREQUEST'].fields_by_name['id']._serialized_options = b'\272H\006r\004\020\001\030@'
  _globals['_UPDATETELEMETRYCONFIGREQUEST'].fields_by_name['sink_url']._loaded_options = None
  _globals['_UPDATETELEMETRYCONFIGREQUEST'].fields_by_name['sink_url']._serialized_options = b'\272H\005r\003\210\001\001'
  _globals['_UPDATETELEMETRYCONFIGREQUEST'].fields_by_name['protocol']._loaded_options = None
  _globals['_UPDATETELEMETRYCONFIGREQUEST'].fields_by_name['protocol']._serialized_options = b'\272H\"r R\004grpcR\thttp/jsonR\rhttp/protobuf'
  _globals['_UPDATETELEMETRYCONFIGREQUEST'].fields_by_name['auth_type']._loaded_options = None
  _globals['_UPDATETELEMETRYCONFIGREQUEST'].fields_by_name['auth_type']._serialized_options = b'\272H r\036R\004noneR\006bearerR\005basicR\007api_key'
  _globals['_UPDATETELEMETRYCONFIGREQUEST'].fields_by_name['api_key_header']._loaded_options = None
  _globals['_UPDATETELEMETRYCONFIGREQUEST'].fields_by_name['api_key_header']._serialized_options = b'\272H\005r\003\030\200\002'
  _globals['_UPDATETELEMETRYCONFIGREQUEST'].fields_by_name['status']._loaded_options = None
  _globals['_UPDATETELEMETRYCONFIGREQUEST'].fields_by_name['status']._serialized_options = b'\272H+r)R\tconnectedR\014disconnectedR\005errorR\007testing'
  _globals['_DELETETELEMETRYCONFIGREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_DELETETELEMETRYCONFIGREQUEST'].fields_by_name['id']._serialized_options = b'\272H\006r\004\020\001\030@'
  _globals['_CUSTOMER_LABELSENTRY']._loaded_options = None
  _globals['_CUSTOMER_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATECUSTOMERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATECUSTOMERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATECUSTOMERREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_CREATECUSTOMERREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H\'r%\020\001\030?2\037^[a-z0-9]([a-z0-9-]*[a-z0-9])?$'
  _globals['_CREATECUSTOMERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATECUSTOMERREQUEST'].fields_by_name['name']._serialized_options = b'\272H\005r\003\030\377\001'
  _globals['_CREATECUSTOMERREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATECUSTOMERREQUEST'].fields_by_name['description']._serialized_options = b'\272H\005r\003\030\350\007'
  _globals['_LISTCUSTOMERSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCUSTOMERSREQUEST'].fields_by_name['page_size']._serialized_options = b'\272H\007\032\005\030\350\007(\000'
  _globals['_GETCUSTOMERREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_GETCUSTOMERREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H\006r\004\020\001\030?'
  _globals['_UPDATECUSTOMERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATECUSTOMERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATECUSTOMERREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_UPDATECUSTOMERREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H\006r\004\020\001\030?'
  _globals['_UPDATECUSTOMERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATECUSTOMERREQUEST'].fields_by_name['name']._serialized_options = b'\272H\005r\003\030\377\001'
  _globals['_UPDATECUSTOMERREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATECUSTOMERREQUEST'].fields_by_name['description']._serialized_options = b'\272H\005r\003\030\350\007'
  _globals['_DELETECUSTOMERREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_DELETECUSTOMERREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H\006r\004\020\001\030?'
  _globals['_PROJECT_LABELSENTRY']._loaded_options = None
  _globals['_PROJECT_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEPROJECTREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEPROJECTREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEPROJECTREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_CREATEPROJECTREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H\006r\004\020\001\030?'
  _globals['_CREATEPROJECTREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_CREATEPROJECTREQUEST'].fields_by_name['project_id']._serialized_options = b'\272H*r(\020\001\030\375\0012!^[a-z0-9]([a-z0-9-_.]*[a-z0-9])?$'
  _globals['_CREATEPROJECTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEPROJECTREQUEST'].fields_by_name['name']._serialized_options = b'\272H\005r\003\030\377\001'
  _globals['_CREATEPROJECTREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEPROJECTREQUEST'].fields_by_name['description']._serialized_options = b'\272H\005r\003\030\350\007'
  _globals['_LISTPROJECTSREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_LISTPROJECTSREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H\006r\004\020\001\030?'
  _globals['_LISTPROJECTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTPROJECTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\272H\007\032\005\030\350\007(\000'
  _globals['_GETPROJECTREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_GETPROJECTREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H\006r\004\020\001\030?'
  _globals['_GETPROJECTREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_GETPROJECTREQUEST'].fields_by_name['project_id']._serialized_options = b'\272H\007r\005\020\001\030\375\001'
  _globals['_UPDATEPROJECTREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEPROJECTREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEPROJECTREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_UPDATEPROJECTREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H\006r\004\020\001\030?'
  _globals['_UPDATEPROJECTREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_UPDATEPROJECTREQUEST'].fields_by_name['project_id']._serialized_options = b'\272H\007r\005\020\001\030\375\001'
  _globals['_UPDATEPROJECTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEPROJECTREQUEST'].fields_by_name['name']._serialized_options = b'\272H\005r\003\030\377\001'
  _globals['_UPDATEPROJECTREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEPROJECTREQUEST'].fields_by_name['description']._serialized_options = b'\272H\005r\003\030\350\007'
  _globals['_DELETEPROJECTREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_DELETEPROJECTREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H\006r\004\020\001\030?'
  _globals['_DELETEPROJECTREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_DELETEPROJECTREQUEST'].fields_by_name['project_id']._serialized_options = b'\272H\007r\005\020\001\030\375\001'
  _globals['_ADDPROJECTMEMBERREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_ADDPROJECTMEMBERREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H\006r\004\020\001\030?'
  _globals['_ADDPROJECTMEMBERREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_ADDPROJECTMEMBERREQUEST'].fields_by_name['project_id']._serialized_options = b'\272H\007r\005\020\001\030\375\001'
  _globals['_ADDPROJECTMEMBERREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_ADDPROJECTMEMBERREQUEST'].fields_by_name['user_id']._serialized_options = b'\272H\007r\005\020\001\030\377\001'
  _globals['_ADDPROJECTMEMBERREQUEST'].fields_by_name['role']._loaded_options = None
  _globals['_ADDPROJECTMEMBERREQUEST'].fields_by_name['role']._serialized_options = b'\272H\021r\017R\005adminR\006member'
  _globals['_LISTPROJECTMEMBERSREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_LISTPROJECTMEMBERSREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H\006r\004\020\001\030?'
  _globals['_LISTPROJECTMEMBERSREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_LISTPROJECTMEMBERSREQUEST'].fields_by_name['project_id']._serialized_options = b'\272H\007r\005\020\001\030\375\001'
  _globals['_UPDATEPROJECTMEMBERREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_UPDATEPROJECTMEMBERREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H\006r\004\020\001\030?'
  _globals['_UPDATEPROJECTMEMBERREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_UPDATEPROJECTMEMBERREQUEST'].fields_by_name['project_id']._serialized_options = b'\272H\007r\005\020\001\030\375\001'
  _globals['_UPDATEPROJECTMEMBERREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_UPDATEPROJECTMEMBERREQUEST'].fields_by_name['user_id']._serialized_options = b'\272H\007r\005\020\001\030\377\001'
  _globals['_UPDATEPROJECTMEMBERREQUEST'].fields_by_name['role']._loaded_options = None
  _globals['_UPDATEPROJECTMEMBERREQUEST'].fields_by_name['role']._serialized_options = b'\272H\021r\017R\005adminR\006member'
  _globals['_REMOVEPROJECTMEMBERREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_REMOVEPROJECTMEMBERREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H\006r\004\020\001\030?'
  _globals['_REMOVEPROJECTMEMBERREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_REMOVEPROJECTMEMBERREQUEST'].fields_by_name['project_id']._serialized_options = b'\272H\007r\005\020\001\030\375\001'
  _globals['_REMOVEPROJECTMEMBERREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_REMOVEPROJECTMEMBERREQUEST'].fields_by_name['user_id']._serialized_options = b'\272H\007r\005\020\001\030\377\001'
  _globals['_GETMODELREQUEST'].fields_by_name['model_id']._loaded_options = None
  _globals['_GETMODELREQUEST'].fields_by_name['model_id']._serialized_options = b'\272HBr@2>^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$'
  _globals['_ADDPROJECTMODELREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_ADDPROJECTMODELREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H\006r\004\020\001\030?'
  _globals['_ADDPROJECTMODELREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_ADDPROJECTMODELREQUEST'].fields_by_name['project_id']._serialized_options = b'\272H\007r\005\020\001\030\375\001'
  _globals['_ADDPROJECTMODELREQUEST'].fields_by_name['model_id']._loaded_options = None
  _globals['_ADDPROJECTMODELREQUEST'].fields_by_name['model_id']._serialized_options = b'\272HBr@2>^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$'
  _globals['_LISTPROJECTMODELSREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_LISTPROJECTMODELSREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H\006r\004\020\001\030?'
  _globals['_LISTPROJECTMODELSREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_LISTPROJECTMODELSREQUEST'].fields_by_name['project_id']._serialized_options = b'\272H\007r\005\020\001\030\375\001'
  _globals['_REMOVEPROJECTMODELREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_REMOVEPROJECTMODELREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H\006r\004\020\001\030?'
  _globals['_REMOVEPROJECTMODELREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_REMOVEPROJECTMODELREQUEST'].fields_by_name['project_id']._serialized_options = b'\272H\007r\005\020\001\030\375\001'
  _globals['_REMOVEPROJECTMODELREQUEST'].fields_by_name['model_id']._loaded_options = None
  _globals['_REMOVEPROJECTMODELREQUEST'].fields_by_name['model_id']._serialized_options = b'\272HBr@2>^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$'
  _globals['_ADDPROJECTPROVIDERREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_ADDPROJECTPROVIDERREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H\006r\004\020\001\030?'
  _globals['_ADDPROJECTPROVIDERREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_ADDPROJECTPROVIDERREQUEST'].fields_by_name['project_id']._serialized_options = b'\272H\007r\005\020\001\030\375\001'
  _globals['_ADDPROJECTPROVIDERREQUEST'].fields_by_name['provider_name']._loaded_options = None
  _globals['_ADDPROJECTPROVIDERREQUEST'].fields_by_name['provider_name']._serialized_options = b'\272H\006r\004\020\001\030?'
  _globals['_LISTPROJECTPROVIDERSREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_LISTPROJECTPROVIDERSREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H\006r\004\020\001\030?'
  _globals['_LISTPROJECTPROVIDERSREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_LISTPROJECTPROVIDERSREQUEST'].fields_by_name['project_id']._serialized_options = b'\272H\007r\005\020\001\030\375\001'
  _globals['_REMOVEPROJECTPROVIDERREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_REMOVEPROJECTPROVIDERREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H\006r\004\020\001\030?'
  _globals['_REMOVEPROJECTPROVIDERREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_REMOVEPROJECTPROVIDERREQUEST'].fields_by_name['project_id']._serialized_options = b'\272H\007r\005\020\001\030\375\001'
  _globals['_REMOVEPROJECTPROVIDERREQUEST'].fields_by_name['provider_name']._loaded_options = None
  _globals['_REMOVEPROJECTPROVIDERREQUEST'].fields_by_name['provider_name']._serialized_options = b'\272H\006r\004\020\001\030?'
  _globals['_ADDPROJECTMCPSERVERREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_ADDPROJECTMCPSERVERREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H\006r\004\020\001\030?'
  _globals['_ADDPROJECTMCPSERVERREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_ADDPROJECTMCPSERVERREQUEST'].fields_by_name['project_id']._serialized_options = b'\272H\007r\005\020\001\030\375\001'
  _globals['_ADDPROJECTMCPSERVERREQUEST'].fields_by_name['server_id']._loaded_options = None
  _globals['_ADDPROJECTMCPSERVERREQUEST'].fields_by_name['server_id']._serialized_options = b'\272H3r1\020\001\030\375\0012*^[a-zA-Z0-9]([a-zA-Z0-9._-]*[a-zA-Z0-9])?$'
  _globals['_LISTPROJECTMCPSERVERSREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_LISTPROJECTMCPSERVERSREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H\006r\004\020\001\030?'
  _globals['_LISTPROJECTMCPSERVERSREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_LISTPROJECTMCPSERVERSREQUEST'].fields_by_name['project_id']._serialized_options = b'\272H\007r\005\020\001\030\375\001'
  _globals['_REMOVEPROJECTMCPSERVERREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_REMOVEPROJECTMCPSERVERREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H\006r\004\020\001\030?'
  _globals['_REMOVEPROJECTMCPSERVERREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_REMOVEPROJECTMCPSERVERREQUEST'].fields_by_name['project_id']._serialized_options = b'\272H\007r\005\020\001\030\375\001'
  _globals['_REMOVEPROJECTMCPSERVERREQUEST'].fields_by_name['server_id']._loaded_options = None
  _globals['_REMOVEPROJECTMCPSERVERREQUEST'].fields_by_name['server_id']._serialized_options = b'\272H3r1\020\001\030\375\0012*^[a-zA-Z0-9]([a-zA-Z0-9._-]*[a-zA-Z0-9])?$'
  _globals['_GETPROJECTSETTINGSREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_GETPROJECTSETTINGSREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H\006r\004\020\001\030?'
  _globals['_GETPROJECTSETTINGSREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_GETPROJECTSETTINGSREQUEST'].fields_by_name['project_id']._serialized_options = b'\272H\007r\005\020\001\030\375\001'
  _globals['_UPSERTPROJECTSETTINGREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_UPSERTPROJECTSETTINGREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H\006r\004\020\001\030?'
  _globals['_UPSERTPROJECTSETTINGREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_UPSERTPROJECTSETTINGREQUEST'].fields_by_name['project_id']._serialized_options = b'\272H\007r\005\020\001\030\375\001'
  _globals['_UPSERTPROJECTSETTINGREQUEST'].fields_by_name['setting_name']._loaded_options = None
  _globals['_UPSERTPROJECTSETTINGREQUEST'].fields_by_name['setting_name']._serialized_options = b'\272H\037r\035R\017global-fallbackR\nrate-limit'
  _globals['_UPSERTPROJECTSETTINGREQUEST'].fields_by_name['setting_value']._loaded_options = None
  _globals['_UPSERTPROJECTSETTINGREQUEST'].fields_by_name['setting_value']._serialized_options = b'\272H\007r\005\020\001\030\200\010'
  _globals['_DELETEPROJECTSETTINGREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_DELETEPROJECTSETTINGREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H\006r\004\020\001\030?'
  _globals['_DELETEPROJECTSETTINGREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_DELETEPROJECTSETTINGREQUEST'].fields_by_name['project_id']._serialized_options = b'\272H\007r\005\020\001\030\375\001'
  _globals['_DELETEPROJECTSETTINGREQUEST'].fields_by_name['setting_name']._loaded_options = None
  _globals['_DELETEPROJECTSETTINGREQUEST'].fields_by_name['setting_name']._serialized_options = b'\272H\037r\035R\017global-fallbackR\nrate-limit'
  _globals['_ADMINSERVICE'].methods_by_name['Ping']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['Ping']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\202\323\344\223\002\020\022\016/admin/v1/ping'
  _globals['_ADMINSERVICE'].methods_by_name['CreateWorkspace']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['CreateWorkspace']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\nWorkspaces\202\323\344\223\002\031\"\024/admin/v1/workspaces:\001*'
  _globals['_ADMINSERVICE'].methods_by_name['ListWorkspaces']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['ListWorkspaces']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\252\265\030\nWorkspaces\202\323\344\223\002\026\022\024/admin/v1/workspaces'
  _globals['_ADMINSERVICE'].methods_by_name['GetWorkspace']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['GetWorkspace']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\252\265\030\nWorkspaces\202\323\344\223\002\033\022\031/admin/v1/workspaces/{id}'
  _globals['_ADMINSERVICE'].methods_by_name['UpdateWorkspace']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['UpdateWorkspace']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\nWorkspaces\202\323\344\223\002\0362\031/admin/v1/workspaces/{id}:\001*'
  _globals['_ADMINSERVICE'].methods_by_name['SetWorkspaceURL']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['SetWorkspaceURL']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\nWorkspaces\202\323\344\223\002\"\"\035/admin/v1/workspaces/{id}/url:\001*'
  _globals['_ADMINSERVICE'].methods_by_name['SetWorkspaceProject']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['SetWorkspaceProject']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\nWorkspaces\202\323\344\223\002&\"!/admin/v1/workspaces/{id}/project:\001*'
  _globals['_ADMINSERVICE'].methods_by_name['DeleteWorkspace']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['DeleteWorkspace']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\nWorkspaces\202\323\344\223\002\033*\031/admin/v1/workspaces/{id}'
  _globals['_ADMINSERVICE'].methods_by_name['CreateServiceAccount']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['CreateServiceAccount']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\020Service Accounts\202\323\344\223\002\037\"\032/admin/v1/service-accounts:\001*'
  _globals['_ADMINSERVICE'].methods_by_name['ListServiceAccounts']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['ListServiceAccounts']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\252\265\030\020Service Accounts\202\323\344\223\002\034\022\032/admin/v1/service-accounts'
  _globals['_ADMINSERVICE'].methods_by_name['GetServiceAccount']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['GetServiceAccount']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\252\265\030\020Service Accounts\202\323\344\223\002!\022\037/admin/v1/service-accounts/{id}'
  _globals['_ADMINSERVICE'].methods_by_name['RevokeServiceAccount']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['RevokeServiceAccount']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\020Service Accounts\202\323\344\223\002+\"&/admin/v1/service-accounts/{id}:revoke:\001*'
  _globals['_ADMINSERVICE'].methods_by_name['RestoreServiceAccount']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['RestoreServiceAccount']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\020Service Accounts\202\323\344\223\002,\"\'/admin/v1/service-accounts/{id}:restore:\001*'
  _globals['_ADMINSERVICE'].methods_by_name['CreateUserToken']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['CreateUserToken']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\013User Tokens\202\323\344\223\002\032\"\025/admin/v1/user-tokens:\001*'
  _globals['_ADMINSERVICE'].methods_by_name['ListUserTokens']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['ListUserTokens']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\252\265\030\013User Tokens\202\323\344\223\002\027\022\025/admin/v1/user-tokens'
  _globals['_ADMINSERVICE'].methods_by_name['GetUserToken']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['GetUserToken']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\252\265\030\013User Tokens\202\323\344\223\002\035\022\033/admin/v1/user-tokens/{jti}'
  _globals['_ADMINSERVICE'].methods_by_name['RevokeUserToken']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['RevokeUserToken']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\013User Tokens\202\323\344\223\002\'\"\"/admin/v1/user-tokens/{jti}:revoke:\001*'
  _globals['_ADMINSERVICE'].methods_by_name['CreateTelemetryConfig']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['CreateTelemetryConfig']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\tTelemetry\202\323\344\223\002 \"\033/admin/v1/telemetry-configs:\001*'
  _globals['_ADMINSERVICE'].methods_by_name['ListTelemetryConfigs']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['ListTelemetryConfigs']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\252\265\030\tTelemetry\202\323\344\223\002\035\022\033/admin/v1/telemetry-configs'
  _globals['_ADMINSERVICE'].methods_by_name['GetTelemetryConfig']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['GetTelemetryConfig']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\252\265\030\tTelemetry\202\323\344\223\002\"\022 /admin/v1/telemetry-configs/{id}'
  _globals['_ADMINSERVICE'].methods_by_name['UpdateTelemetryConfig']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['UpdateTelemetryConfig']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\tTelemetry\202\323\344\223\002%2 /admin/v1/telemetry-configs/{id}:\001*'
  _globals['_ADMINSERVICE'].methods_by_name['DeleteTelemetryConfig']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['DeleteTelemetryConfig']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\tTelemetry\202\323\344\223\002\"* /admin/v1/telemetry-configs/{id}'
  _globals['_ADMINSERVICE'].methods_by_name['CreateCustomer']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['CreateCustomer']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\tCustomers\202\323\344\223\002\030\"\023/admin/v1/customers:\001*'
  _globals['_ADMINSERVICE'].methods_by_name['ListCustomers']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['ListCustomers']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\252\265\030\tCustomers\202\323\344\223\002\025\022\023/admin/v1/customers'
  _globals['_ADMINSERVICE'].methods_by_name['GetCustomer']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['GetCustomer']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\252\265\030\tCustomers\202\323\344\223\002#\022!/admin/v1/customers/{customer_id}'
  _globals['_ADMINSERVICE'].methods_by_name['UpdateCustomer']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['UpdateCustomer']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\tCustomers\202\323\344\223\002&2!/admin/v1/customers/{customer_id}:\001*'
  _globals['_ADMINSERVICE'].methods_by_name['DeleteCustomer']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['DeleteCustomer']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\tCustomers\202\323\344\223\002#*!/admin/v1/customers/{customer_id}'
  _globals['_ADMINSERVICE'].methods_by_name['CreateProject']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['CreateProject']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\010Projects\202\323\344\223\002/\"*/admin/v1/customers/{customer_id}/projects:\001*'
  _globals['_ADMINSERVICE'].methods_by_name['ListProjects']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['ListProjects']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\252\265\030\010Projects\202\323\344\223\002,\022*/admin/v1/customers/{customer_id}/projects'
  _globals['_ADMINSERVICE'].methods_by_name['GetProject']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['GetProject']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\252\265\030\010Projects\202\323\344\223\0029\0227/admin/v1/customers/{customer_id}/projects/{project_id}'
  _globals['_ADMINSERVICE'].methods_by_name['UpdateProject']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['UpdateProject']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\010Projects\202\323\344\223\002<27/admin/v1/customers/{customer_id}/projects/{project_id}:\001*'
  _globals['_ADMINSERVICE'].methods_by_name['DeleteProject']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['DeleteProject']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\010Projects\202\323\344\223\0029*7/admin/v1/customers/{customer_id}/projects/{project_id}'
  _globals['_ADMINSERVICE'].methods_by_name['AddProjectMember']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['AddProjectMember']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\017Project Members\202\323\344\223\002D\"?/admin/v1/customers/{customer_id}/projects/{project_id}/members:\001*'
  _globals['_ADMINSERVICE'].methods_by_name['ListProjectMembers']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['ListProjectMembers']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\252\265\030\017Project Members\202\323\344\223\002A\022?/admin/v1/customers/{customer_id}/projects/{project_id}/members'
  _globals['_ADMINSERVICE'].methods_by_name['UpdateProjectMember']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['UpdateProjectMember']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\017Project Members\202\323\344\223\002N2I/admin/v1/customers/{customer_id}/projects/{project_id}/members/{user_id}:\001*'
  _globals['_ADMINSERVICE'].methods_by_name['RemoveProjectMember']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['RemoveProjectMember']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\017Project Members\202\323\344\223\002K*I/admin/v1/customers/{customer_id}/projects/{project_id}/members/{user_id}'
  _globals['_ADMINSERVICE'].methods_by_name['ListModels']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['ListModels']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\252\265\030\006Models\202\323\344\223\002\022\022\020/admin/v1/models'
  _globals['_ADMINSERVICE'].methods_by_name['GetModel']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['GetModel']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\252\265\030\006Models\202\323\344\223\002\035\022\033/admin/v1/models/{model_id}'
  _globals['_ADMINSERVICE'].methods_by_name['AddProjectModel']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['AddProjectModel']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\016Project Models\202\323\344\223\002C\">/admin/v1/customers/{customer_id}/projects/{project_id}/models:\001*'
  _globals['_ADMINSERVICE'].methods_by_name['ListProjectModels']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['ListProjectModels']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\252\265\030\016Project Models\202\323\344\223\002@\022>/admin/v1/customers/{customer_id}/projects/{project_id}/models'
  _globals['_ADMINSERVICE'].methods_by_name['RemoveProjectModel']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['RemoveProjectModel']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\016Project Models\202\323\344\223\002K*I/admin/v1/customers/{customer_id}/projects/{project_id}/models/{model_id}'
  _globals['_ADMINSERVICE'].methods_by_name['AddProjectProvider']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['AddProjectProvider']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\021Project Providers\202\323\344\223\002F\"A/admin/v1/customers/{customer_id}/projects/{project_id}/providers:\001*'
  _globals['_ADMINSERVICE'].methods_by_name['ListProjectProviders']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['ListProjectProviders']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\252\265\030\021Project Providers\202\323\344\223\002C\022A/admin/v1/customers/{customer_id}/projects/{project_id}/providers'
  _globals['_ADMINSERVICE'].methods_by_name['RemoveProjectProvider']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['RemoveProjectProvider']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\021Project Providers\202\323\344\223\002S*Q/admin/v1/customers/{customer_id}/projects/{project_id}/providers/{provider_name}'
  _globals['_ADMINSERVICE'].methods_by_name['AddProjectMcpServer']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['AddProjectMcpServer']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\023Project MCP Servers\202\323\344\223\002H\"C/admin/v1/customers/{customer_id}/projects/{project_id}/mcp-servers:\001*'
  _globals['_ADMINSERVICE'].methods_by_name['ListProjectMcpServers']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['ListProjectMcpServers']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\252\265\030\023Project MCP Servers\202\323\344\223\002E\022C/admin/v1/customers/{customer_id}/projects/{project_id}/mcp-servers'
  _globals['_ADMINSERVICE'].methods_by_name['RemoveProjectMcpServer']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['RemoveProjectMcpServer']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\023Project MCP Servers\202\323\344\223\002Q*O/admin/v1/customers/{customer_id}/projects/{project_id}/mcp-servers/{server_id}'
  _globals['_ADMINSERVICE'].methods_by_name['GetProjectSettings']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['GetProjectSettings']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\252\265\030\020Project Settings\202\323\344\223\002B\022@/admin/v1/customers/{customer_id}/projects/{project_id}/settings'
  _globals['_ADMINSERVICE'].methods_by_name['UpsertProjectSetting']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['UpsertProjectSetting']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\020Project Settings\202\323\344\223\002T\032O/admin/v1/customers/{customer_id}/projects/{project_id}/settings/{setting_name}:\001*'
  _globals['_ADMINSERVICE'].methods_by_name['DeleteProjectSetting']._loaded_options = None
  _globals['_ADMINSERVICE'].methods_by_name['DeleteProjectSetting']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\020Project Settings\202\323\344\223\002Q*O/admin/v1/customers/{customer_id}/projects/{project_id}/settings/{setting_name}'
  _globals['_SERVICEACCOUNTSTATUS']._serialized_start=22853
  _globals['_SERVICEACCOUNTSTATUS']._serialized_end=23022
  _globals['_USERTOKENSTATUS']._serialized_start=23025
  _globals['_USERTOKENSTATUS']._serialized_end=23169
  _globals['_PINGREQUEST']._serialized_start=194
  _globals['_PINGREQUEST']._serialized_end=207
  _globals['_PINGRESPONSE']._serialized_start=209
  _globals['_PINGRESPONSE']._serialized_end=307
  _globals['_CREATEWORKSPACEREQUEST']._serialized_start=310
  _globals['_CREATEWORKSPACEREQUEST']._serialized_end=840
  _globals['_CREATEWORKSPACEREQUEST_LABELSENTRY']._serialized_start=743
  _globals['_CREATEWORKSPACEREQUEST_LABELSENTRY']._serialized_end=800
  _globals['_CREATEWORKSPACERESPONSE']._serialized_start=842
  _globals['_CREATEWORKSPACERESPONSE']._serialized_end=923
  _globals['_LISTWORKSPACESREQUEST']._serialized_start=926
  _globals['_LISTWORKSPACESREQUEST']._serialized_end=1156
  _globals['_LISTWORKSPACESRESPONSE']._serialized_start=1158
  _globals['_LISTWORKSPACESRESPONSE']._serialized_end=1280
  _globals['_GETWORKSPACEREQUEST']._serialized_start=1282
  _globals['_GETWORKSPACEREQUEST']._serialized_end=1390
  _globals['_GETWORKSPACERESPONSE']._serialized_start=1392
  _globals['_GETWORKSPACERESPONSE']._serialized_end=1470
  _globals['_UPDATEWORKSPACEREQUEST']._serialized_start=1473
  _globals['_UPDATEWORKSPACEREQUEST']._serialized_end=1886
  _globals['_UPDATEWORKSPACEREQUEST_LABELSENTRY']._serialized_start=743
  _globals['_UPDATEWORKSPACEREQUEST_LABELSENTRY']._serialized_end=800
  _globals['_UPDATEWORKSPACERESPONSE']._serialized_start=1888
  _globals['_UPDATEWORKSPACERESPONSE']._serialized_end=1969
  _globals['_SETWORKSPACEPROJECTREQUEST']._serialized_start=1972
  _globals['_SETWORKSPACEPROJECTREQUEST']._serialized_end=2148
  _globals['_SETWORKSPACEPROJECTRESPONSE']._serialized_start=2150
  _globals['_SETWORKSPACEPROJECTRESPONSE']._serialized_end=2235
  _globals['_SETWORKSPACEURLREQUEST']._serialized_start=2238
  _globals['_SETWORKSPACEURLREQUEST']._serialized_end=2418
  _globals['_SETWORKSPACEURLRESPONSE']._serialized_start=2420
  _globals['_SETWORKSPACEURLRESPONSE']._serialized_end=2501
  _globals['_DELETEWORKSPACEREQUEST']._serialized_start=2503
  _globals['_DELETEWORKSPACEREQUEST']._serialized_end=2614
  _globals['_DELETEWORKSPACERESPONSE']._serialized_start=2616
  _globals['_DELETEWORKSPACERESPONSE']._serialized_end=2726
  _globals['_WORKSPACE']._serialized_start=2729
  _globals['_WORKSPACE']._serialized_end=3262
  _globals['_WORKSPACE_LABELSENTRY']._serialized_start=743
  _globals['_WORKSPACE_LABELSENTRY']._serialized_end=800
  _globals['_CREATESERVICEACCOUNTREQUEST']._serialized_start=3265
  _globals['_CREATESERVICEACCOUNTREQUEST']._serialized_end=4772
  _globals['_CREATESERVICEACCOUNTREQUEST_TELEMETRYHEADERSENTRY']._serialized_start=4411
  _globals['_CREATESERVICEACCOUNTREQUEST_TELEMETRYHEADERSENTRY']._serialized_end=4478
  _globals['_CREATESERVICEACCOUNTREQUEST_TELEMETRYLOCALVARSENTRY']._serialized_start=4480
  _globals['_CREATESERVICEACCOUNTREQUEST_TELEMETRYLOCALVARSENTRY']._serialized_end=4549
  _globals['_CREATESERVICEACCOUNTRESPONSE']._serialized_start=4775
  _globals['_CREATESERVICEACCOUNTRESPONSE']._serialized_end=4952
  _globals['_SERVICEACCOUNT']._serialized_start=4955
  _globals['_SERVICEACCOUNT']._serialized_end=5577
  _globals['_AUTHSERVERCONFIG']._serialized_start=5580
  _globals['_AUTHSERVERCONFIG']._serialized_end=5736
  _globals['_GATEKEEPERCONFIG']._serialized_start=5739
  _globals['_GATEKEEPERCONFIG']._serialized_end=5921
  _globals['_ROUTERCONFIG']._serialized_start=5923
  _globals['_ROUTERCONFIG']._serialized_end=5983
  _globals['_PUBLICKEY']._serialized_start=5985
  _globals['_PUBLICKEY']._serialized_end=6068
  _globals['_DATAEXPORTSCONFIG']._serialized_start=6070
  _globals['_DATAEXPORTSCONFIG']._serialized_end=6151
  _globals['_TELEMETRYCONFIG']._serialized_start=6154
  _globals['_TELEMETRYCONFIG']._serialized_end=6412
  _globals['_TELEMETRYCONFIG_HEADERSENTRY']._serialized_start=6354
  _globals['_TELEMETRYCONFIG_HEADERSENTRY']._serialized_end=6412
  _globals['_LISTSERVICEACCOUNTSREQUEST']._serialized_start=6415
  _globals['_LISTSERVICEACCOUNTSREQUEST']._serialized_end=6813
  _globals['_LISTSERVICEACCOUNTSRESPONSE']._serialized_start=6816
  _globals['_LISTSERVICEACCOUNTSRESPONSE']._serialized_end=6963
  _globals['_GETSERVICEACCOUNTREQUEST']._serialized_start=6965
  _globals['_GETSERVICEACCOUNTREQUEST']._serialized_end=7078
  _globals['_GETSERVICEACCOUNTRESPONSE']._serialized_start=7080
  _globals['_GETSERVICEACCOUNTRESPONSE']._serialized_end=7183
  _globals['_SERVICEACCOUNTINFO']._serialized_start=7186
  _globals['_SERVICEACCOUNTINFO']._serialized_end=7846
  _globals['_SERVICEACCOUNTINFO_METADATAENTRY']._serialized_start=7755
  _globals['_SERVICEACCOUNTINFO_METADATAENTRY']._serialized_end=7814
  _globals['_REVOKESERVICEACCOUNTREQUEST']._serialized_start=7849
  _globals['_REVOKESERVICEACCOUNTREQUEST']._serialized_end=8015
  _globals['_REVOKESERVICEACCOUNTRESPONSE']._serialized_start=8017
  _globals['_REVOKESERVICEACCOUNTRESPONSE']._serialized_end=8132
  _globals['_RESTORESERVICEACCOUNTREQUEST']._serialized_start=8135
  _globals['_RESTORESERVICEACCOUNTREQUEST']._serialized_end=8302
  _globals['_RESTORESERVICEACCOUNTRESPONSE']._serialized_start=8305
  _globals['_RESTORESERVICEACCOUNTRESPONSE']._serialized_end=8438
  _globals['_CREATEUSERTOKENREQUEST']._serialized_start=8441
  _globals['_CREATEUSERTOKENREQUEST']._serialized_end=9064
  _globals['_IMPERSONATIONMETADATA']._serialized_start=9067
  _globals['_IMPERSONATIONMETADATA']._serialized_end=9332
  _globals['_IMPERSONATIONMETADATA_CONTEXTENTRY']._serialized_start=9263
  _globals['_IMPERSONATIONMETADATA_CONTEXTENTRY']._serialized_end=9321
  _globals['_CREATEUSERTOKENRESPONSE']._serialized_start=9335
  _globals['_CREATEUSERTOKENRESPONSE']._serialized_end=9625
  _globals['_LISTUSERTOKENSREQUEST']._serialized_start=9628
  _globals['_LISTUSERTOKENSREQUEST']._serialized_end=9886
  _globals['_LISTUSERTOKENSRESPONSE']._serialized_start=9888
  _globals['_LISTUSERTOKENSRESPONSE']._serialized_end=10006
  _globals['_GETUSERTOKENREQUEST']._serialized_start=10008
  _globals['_GETUSERTOKENREQUEST']._serialized_end=10058
  _globals['_GETUSERTOKENRESPONSE']._serialized_start=10060
  _globals['_GETUSERTOKENRESPONSE']._serialized_end=10134
  _globals['_USERTOKENINFO']._serialized_start=10137
  _globals['_USERTOKENINFO']._serialized_end=10660
  _globals['_REVOKEUSERTOKENREQUEST']._serialized_start=10662
  _globals['_REVOKEUSERTOKENREQUEST']._serialized_end=10765
  _globals['_REVOKEUSERTOKENRESPONSE']._serialized_start=10767
  _globals['_REVOKEUSERTOKENRESPONSE']._serialized_end=10877
  _globals['_TELEMETRYFORWARDINGCONFIG']._serialized_start=10880
  _globals['_TELEMETRYFORWARDINGCONFIG']._serialized_end=11420
  _globals['_CREATETELEMETRYCONFIGREQUEST']._serialized_start=11423
  _globals['_CREATETELEMETRYCONFIGREQUEST']._serialized_end=11894
  _globals['_CREATETELEMETRYCONFIGRESPONSE']._serialized_start=11896
  _globals['_CREATETELEMETRYCONFIGRESPONSE']._serialized_end=11993
  _globals['_LISTTELEMETRYCONFIGSREQUEST']._serialized_start=11996
  _globals['_LISTTELEMETRYCONFIGSREQUEST']._serialized_end=12203
  _globals['_LISTTELEMETRYCONFIGSRESPONSE']._serialized_start=12205
  _globals['_LISTTELEMETRYCONFIGSRESPONSE']._serialized_end=12325
  _globals['_GETTELEMETRYCONFIGREQUEST']._serialized_start=12327
  _globals['_GETTELEMETRYCONFIGREQUEST']._serialized_end=12381
  _globals['_GETTELEMETRYCONFIGRESPONSE']._serialized_start=12383
  _globals['_GETTELEMETRYCONFIGRESPONSE']._serialized_end=12477
  _globals['_UPDATETELEMETRYCONFIGREQUEST']._serialized_start=12480
  _globals['_UPDATETELEMETRYCONFIGREQUEST']._serialized_end=13016
  _globals['_UPDATETELEMETRYCONFIGRESPONSE']._serialized_start=13018
  _globals['_UPDATETELEMETRYCONFIGRESPONSE']._serialized_end=13115
  _globals['_DELETETELEMETRYCONFIGREQUEST']._serialized_start=13117
  _globals['_DELETETELEMETRYCONFIGREQUEST']._serialized_end=13174
  _globals['_DELETETELEMETRYCONFIGRESPONSE']._serialized_start=13176
  _globals['_DELETETELEMETRYCONFIGRESPONSE']._serialized_end=13233
  _globals['_CUSTOMER']._serialized_start=13236
  _globals['_CUSTOMER']._serialized_end=13701
  _globals['_CUSTOMER_LABELSENTRY']._serialized_start=743
  _globals['_CUSTOMER_LABELSENTRY']._serialized_end=800
  _globals['_CREATECUSTOMERREQUEST']._serialized_start=13704
  _globals['_CREATECUSTOMERREQUEST']._serialized_end=14046
  _globals['_CREATECUSTOMERREQUEST_LABELSENTRY']._serialized_start=743
  _globals['_CREATECUSTOMERREQUEST_LABELSENTRY']._serialized_end=800
  _globals['_CREATECUSTOMERRESPONSE']._serialized_start=14048
  _globals['_CREATECUSTOMERRESPONSE']._serialized_end=14125
  _globals['_LISTCUSTOMERSREQUEST']._serialized_start=14128
  _globals['_LISTCUSTOMERSREQUEST']._serialized_end=14261
  _globals['_LISTCUSTOMERSRESPONSE']._serialized_start=14263
  _globals['_LISTCUSTOMERSRESPONSE']._serialized_end=14381
  _globals['_GETCUSTOMERREQUEST']._serialized_start=14383
  _globals['_GETCUSTOMERREQUEST']._serialized_end=14447
  _globals['_GETCUSTOMERRESPONSE']._serialized_start=14449
  _globals['_GETCUSTOMERRESPONSE']._serialized_end=14523
  _globals['_UPDATECUSTOMERREQUEST']._serialized_start=14526
  _globals['_UPDATECUSTOMERREQUEST']._serialized_end=14835
  _globals['_UPDATECUSTOMERREQUEST_LABELSENTRY']._serialized_start=743
  _globals['_UPDATECUSTOMERREQUEST_LABELSENTRY']._serialized_end=800
  _globals['_UPDATECUSTOMERRESPONSE']._serialized_start=14837
  _globals['_UPDATECUSTOMERRESPONSE']._serialized_end=14914
  _globals['_DELETECUSTOMERREQUEST']._serialized_start=14916
  _globals['_DELETECUSTOMERREQUEST']._serialized_end=14983
  _globals['_DELETECUSTOMERRESPONSE']._serialized_start=14985
  _globals['_DELETECUSTOMERRESPONSE']._serialized_end=15094
  _globals['_PROJECT']._serialized_start=15097
  _globals['_PROJECT']._serialized_end=15591
  _globals['_PROJECT_LABELSENTRY']._serialized_start=743
  _globals['_PROJECT_LABELSENTRY']._serialized_end=800
  _globals['_CREATEPROJECTREQUEST']._serialized_start=15594
  _globals['_CREATEPROJECTREQUEST']._serialized_end=15979
  _globals['_CREATEPROJECTREQUEST_LABELSENTRY']._serialized_start=743
  _globals['_CREATEPROJECTREQUEST_LABELSENTRY']._serialized_end=800
  _globals['_CREATEPROJECTRESPONSE']._serialized_start=15981
  _globals['_CREATEPROJECTRESPONSE']._serialized_end=16054
  _globals['_LISTPROJECTSREQUEST']._serialized_start=16057
  _globals['_LISTPROJECTSREQUEST']._serialized_end=16233
  _globals['_LISTPROJECTSRESPONSE']._serialized_start=16235
  _globals['_LISTPROJECTSRESPONSE']._serialized_end=16349
  _globals['_GETPROJECTREQUEST']._serialized_start=16351
  _globals['_GETPROJECTREQUEST']._serialized_end=16457
  _globals['_GETPROJECTRESPONSE']._serialized_start=16459
  _globals['_GETPROJECTRESPONSE']._serialized_end=16529
  _globals['_UPDATEPROJECTREQUEST']._serialized_start=16532
  _globals['_UPDATEPROJECTREQUEST']._serialized_end=16882
  _globals['_UPDATEPROJECTREQUEST_LABELSENTRY']._serialized_start=743
  _globals['_UPDATEPROJECTREQUEST_LABELSENTRY']._serialized_end=800
  _globals['_UPDATEPROJECTRESPONSE']._serialized_start=16884
  _globals['_UPDATEPROJECTRESPONSE']._serialized_end=16957
  _globals['_DELETEPROJECTREQUEST']._serialized_start=16959
  _globals['_DELETEPROJECTREQUEST']._serialized_end=17068
  _globals['_DELETEPROJECTRESPONSE']._serialized_start=17070
  _globals['_DELETEPROJECTRESPONSE']._serialized_end=17178
  _globals['_PROJECTMEMBER']._serialized_start=17181
  _globals['_PROJECTMEMBER']._serialized_end=17439
  _globals['_ADDPROJECTMEMBERREQUEST']._serialized_start=17442
  _globals['_ADDPROJECTMEMBERREQUEST']._serialized_end=17633
  _globals['_ADDPROJECTMEMBERRESPONSE']._serialized_start=17635
  _globals['_ADDPROJECTMEMBERRESPONSE']._serialized_end=17715
  _globals['_LISTPROJECTMEMBERSREQUEST']._serialized_start=17717
  _globals['_LISTPROJECTMEMBERSREQUEST']._serialized_end=17831
  _globals['_LISTPROJECTMEMBERSRESPONSE']._serialized_start=17833
  _globals['_LISTPROJECTMEMBERSRESPONSE']._serialized_end=17917
  _globals['_UPDATEPROJECTMEMBERREQUEST']._serialized_start=17920
  _globals['_UPDATEPROJECTMEMBERREQUEST']._serialized_end=18114
  _globals['_UPDATEPROJECTMEMBERRESPONSE']._serialized_start=18116
  _globals['_UPDATEPROJECTMEMBERRESPONSE']._serialized_end=18199
  _globals['_REMOVEPROJECTMEMBERREQUEST']._serialized_start=18202
  _globals['_REMOVEPROJECTMEMBERREQUEST']._serialized_end=18354
  _globals['_REMOVEPROJECTMEMBERRESPONSE']._serialized_start=18356
  _globals['_REMOVEPROJECTMEMBERRESPONSE']._serialized_end=18411
  _globals['_AIMODEL']._serialized_start=18414
  _globals['_AIMODEL']._serialized_end=18741
  _globals['_LISTMODELSREQUEST']._serialized_start=18743
  _globals['_LISTMODELSREQUEST']._serialized_end=18797
  _globals['_LISTMODELSRESPONSE']._serialized_start=18799
  _globals['_LISTMODELSRESPONSE']._serialized_end=18867
  _globals['_GETMODELREQUEST']._serialized_start=18869
  _globals['_GETMODELREQUEST']._serialized_end=18984
  _globals['_GETMODELRESPONSE']._serialized_start=18986
  _globals['_GETMODELRESPONSE']._serialized_end=19050
  _globals['_PROJECTMODELENTRY']._serialized_start=19053
  _globals['_PROJECTMODELENTRY']._serialized_end=19284
  _globals['_ADDPROJECTMODELREQUEST']._serialized_start=19287
  _globals['_ADDPROJECTMODELREQUEST']._serialized_end=19496
  _globals['_ADDPROJECTMODELRESPONSE']._serialized_start=19498
  _globals['_ADDPROJECTMODELRESPONSE']._serialized_end=19579
  _globals['_LISTPROJECTMODELSREQUEST']._serialized_start=19581
  _globals['_LISTPROJECTMODELSREQUEST']._serialized_end=19694
  _globals['_LISTPROJECTMODELSRESPONSE']._serialized_start=19696
  _globals['_LISTPROJECTMODELSRESPONSE']._serialized_end=19783
  _globals['_REMOVEPROJECTMODELREQUEST']._serialized_start=19786
  _globals['_REMOVEPROJECTMODELREQUEST']._serialized_end=19998
  _globals['_REMOVEPROJECTMODELRESPONSE']._serialized_start=20000
  _globals['_REMOVEPROJECTMODELRESPONSE']._serialized_end=20054
  _globals['_PROJECTPROVIDERENTRY']._serialized_start=20057
  _globals['_PROJECTPROVIDERENTRY']._serialized_end=20255
  _globals['_ADDPROJECTPROVIDERREQUEST']._serialized_start=20258
  _globals['_ADDPROJECTPROVIDERREQUEST']._serialized_end=20420
  _globals['_ADDPROJECTPROVIDERRESPONSE']._serialized_start=20422
  _globals['_ADDPROJECTPROVIDERRESPONSE']._serialized_end=20509
  _globals['_LISTPROJECTPROVIDERSREQUEST']._serialized_start=20511
  _globals['_LISTPROJECTPROVIDERSREQUEST']._serialized_end=20627
  _globals['_LISTPROJECTPROVIDERSRESPONSE']._serialized_start=20629
  _globals['_LISTPROJECTPROVIDERSRESPONSE']._serialized_end=20722
  _globals['_REMOVEPROJECTPROVIDERREQUEST']._serialized_start=20725
  _globals['_REMOVEPROJECTPROVIDERREQUEST']._serialized_end=20890
  _globals['_REMOVEPROJECTPROVIDERRESPONSE']._serialized_start=20892
  _globals['_REMOVEPROJECTPROVIDERRESPONSE']._serialized_end=20949
  _globals['_PROJECTMCPSERVERENTRY']._serialized_start=20952
  _globals['_PROJECTMCPSERVERENTRY']._serialized_end=21143
  _globals['_ADDPROJECTMCPSERVERREQUEST']._serialized_start=21146
  _globals['_ADDPROJECTMCPSERVERREQUEST']._serialized_end=21346
  _globals['_ADDPROJECTMCPSERVERRESPONSE']._serialized_start=21348
  _globals['_ADDPROJECTMCPSERVERRESPONSE']._serialized_end=21437
  _globals['_LISTPROJECTMCPSERVERSREQUEST']._serialized_start=21439
  _globals['_LISTPROJECTMCPSERVERSREQUEST']._serialized_end=21556
  _globals['_LISTPROJECTMCPSERVERSRESPONSE']._serialized_start=21558
  _globals['_LISTPROJECTMCPSERVERSRESPONSE']._serialized_end=21653
  _globals['_REMOVEPROJECTMCPSERVERREQUEST']._serialized_start=21656
  _globals['_REMOVEPROJECTMCPSERVERREQUEST']._serialized_end=21859
  _globals['_REMOVEPROJECTMCPSERVERRESPONSE']._serialized_start=21861
  _globals['_REMOVEPROJECTMCPSERVERRESPONSE']._serialized_end=21919
  _globals['_PROJECTSETTING']._serialized_start=21922
  _globals['_PROJECTSETTING']._serialized_end=22069
  _globals['_GETPROJECTSETTINGSREQUEST']._serialized_start=22071
  _globals['_GETPROJECTSETTINGSREQUEST']._serialized_end=22185
  _globals['_GETPROJECTSETTINGSRESPONSE']._serialized_start=22187
  _globals['_GETPROJECTSETTINGSRESPONSE']._serialized_end=22274
  _globals['_UPSERTPROJECTSETTINGREQUEST']._serialized_start=22277
  _globals['_UPSERTPROJECTSETTINGREQUEST']._serialized_end=22513
  _globals['_UPSERTPROJECTSETTINGRESPONSE']._serialized_start=22515
  _globals['_UPSERTPROJECTSETTINGRESPONSE']._serialized_end=22602
  _globals['_DELETEPROJECTSETTINGREQUEST']._serialized_start=22605
  _globals['_DELETEPROJECTSETTINGREQUEST']._serialized_end=22792
  _globals['_DELETEPROJECTSETTINGRESPONSE']._serialized_start=22794
  _globals['_DELETEPROJECTSETTINGRESPONSE']._serialized_end=22850
  _globals['_ADMINSERVICE']._serialized_start=23172
  _globals['_ADMINSERVICE']._serialized_end=32573
# @@protoc_insertion_point(module_scope)
